<?xml version="1.0" ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>perldebguts - Guts of Perl debugging</title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rev="made" href="mailto:root@localhost" />
</head>

<body style="background-color: white">
<table border="0" width="100%" cellspacing="0" cellpadding="3">
<tr><td class="block" style="background-color: #cccccc" valign="middle">
<big><strong><span class="block">&nbsp;perldebguts - Guts of Perl debugging</span></strong></big>
</td></tr>
</table>

<p><a name="__index__"></a></p>
<!-- INDEX BEGIN -->

<ul>

	<li><a href="#name">NAME</a></li>
	<li><a href="#description">DESCRIPTION</a></li>
	<li><a href="#debugger_internals">Debugger Internals</a></li>
	<ul>

		<li><a href="#writing_your_own_debugger">Writing Your Own Debugger</a></li>
		<ul>

			<li><a href="#environment_variables">Environment Variables</a></li>
			<li><a href="#debugger_internal_variables">Debugger internal variables</a></li>
			<li><a href="#debugger_customization_functions">Debugger customization functions</a></li>
		</ul>

	</ul>

	<li><a href="#frame_listing_output_examples">Frame Listing Output Examples</a></li>
	<li><a href="#debugging_regular_expressions">Debugging regular expressions</a></li>
	<ul>

		<li><a href="#compiletime_output">Compile-time output</a></li>
		<li><a href="#types_of_nodes">Types of nodes</a></li>
		<li><a href="#runtime_output">Run-time output</a></li>
	</ul>

	<li><a href="#debugging_perl_memory_usage">Debugging Perl memory usage</a></li>
	<ul>

		<li><a href="#using__env_perl_debug_mstats_">Using <code>$ENV{PERL_DEBUG_MSTATS}</code></a></li>
	</ul>

	<li><a href="#see_also">SEE ALSO</a></li>
</ul>
<!-- INDEX END -->

<hr />
<p>
</p>
<h1><a name="name">NAME</a></h1>
<p>perldebguts - Guts of Perl debugging</p>
<p>
</p>
<hr />
<h1><a name="description">DESCRIPTION</a></h1>
<p>This is not the <code>perldebug(1)</code> manpage, which tells you how to use
the debugger.  This manpage describes low-level details concerning
the debugger's internals, which range from difficult to impossible
to understand for anyone who isn't incredibly intimate with Perl's guts.
Caveat lector.</p>
<p>
</p>
<hr />
<h1><a name="debugger_internals">Debugger Internals</a></h1>
<p>Perl has special debugging hooks at compile-time and run-time used
to create debugging environments.  These hooks are not to be confused
with the <em>perl -Dxxx</em> command described in <a href="perlrun.html">the perlrun manpage</a>, which is
usable only if a special Perl is built per the instructions in the
<em>INSTALL</em> podpage in the Perl source tree.</p>
<p>For example, whenever you call Perl's built-in <code>caller</code> function
from the package <code>DB</code>, the arguments that the corresponding stack
frame was called with are copied to the <code>@DB::args</code> array.  These
mechanisms are enabled by calling Perl with the <strong>-d</strong> switch.
Specifically, the following additional features are enabled
(cf. <a href="perlvar.html#__p">$^P in the perlvar manpage</a>):</p>
<ul>
<li>
<p>Perl inserts the contents of <code>$ENV{PERL5DB}</code> (or <code>BEGIN {require
'perl5db.pl'}</code> if not present) before the first line of your program.</p>
</li>
<li>
<p>Each array <code>@{&quot;_&lt;$filename&quot;}</code> holds the lines of $filename for a
file compiled by Perl.  The same is also true for <code>eval</code>ed strings
that contain subroutines, or which are currently being executed.
The $filename for <code>eval</code>ed strings looks like <code>(eval 34)</code>.
Code assertions in regexes look like <code>(re_eval 19)</code>.</p>
<p>Values in this array are magical in numeric context: they compare
equal to zero only if the line is not breakable.</p>
</li>
<li>
<p>Each hash <code>%{&quot;_&lt;$filename&quot;}</code> contains breakpoints and actions keyed
by line number.  Individual entries (as opposed to the whole hash)
are settable.  Perl only cares about Boolean true here, although
the values used by <em>perl5db.pl</em> have the form
<code>&quot;$break_condition\0$action&quot;</code>.</p>
<p>The same holds for evaluated strings that contain subroutines, or
which are currently being executed.  The $filename for <code>eval</code>ed strings
looks like <code>(eval 34)</code> or  <code>(re_eval 19)</code>.</p>
</li>
<li>
<p>Each scalar <code>${&quot;_&lt;$filename&quot;}</code> contains <code>&quot;_&lt;$filename&quot;</code>.  This is
also the case for evaluated strings that contain subroutines, or
which are currently being executed.  The $filename for <code>eval</code>ed
strings looks like <code>(eval 34)</code> or <code>(re_eval 19)</code>.</p>
</li>
<li>
<p>After each <code>require</code>d file is compiled, but before it is executed,
<code>DB::postponed(*{&quot;_&lt;$filename&quot;})</code> is called if the subroutine
<code>DB::postponed</code> exists.  Here, the $filename is the expanded name of
the <code>require</code>d file, as found in the values of %INC.</p>
</li>
<li>
<p>After each subroutine <code>subname</code> is compiled, the existence of
<code>$DB::postponed{subname}</code> is checked.  If this key exists,
<code>DB::postponed(subname)</code> is called if the <code>DB::postponed</code> subroutine
also exists.</p>
</li>
<li>
<p>A hash <code>%DB::sub</code> is maintained, whose keys are subroutine names
and whose values have the form <code>filename:startline-endline</code>.
<code>filename</code> has the form <code>(eval 34)</code> for subroutines defined inside
<code>eval</code>s, or <code>(re_eval 19)</code> for those within regex code assertions.</p>
</li>
<li>
<p>When the execution of your program reaches a point that can hold a
breakpoint, the <code>DB::DB()</code> subroutine is called if any of the variables
<code>$DB::trace</code>, <code>$DB::single</code>, or <code>$DB::signal</code> is true.  These variables
are not <code>local</code>izable.  This feature is disabled when executing
inside <code>DB::DB()</code>, including functions called from it 
unless <code>$^D &amp; (1&lt;&lt;30)</code> is true.</p>
</li>
<li>
<p>When execution of the program reaches a subroutine call, a call to
<code>&amp;DB::sub</code>(<em>args</em>) is made instead, with <code>$DB::sub</code> holding the
name of the called subroutine. (This doesn't happen if the subroutine
was compiled in the <code>DB</code> package.)</p>
</li>
</ul>
<p>Note that if <code>&amp;DB::sub</code> needs external data for it to work, no
subroutine call is possible without it. As an example, the standard
debugger's <code>&amp;DB::sub</code> depends on the <code>$DB::deep</code> variable
(it defines how many levels of recursion deep into the debugger you can go
before a mandatory break).  If <code>$DB::deep</code> is not defined, subroutine
calls are not possible, even though <code>&amp;DB::sub</code> exists.</p>
<p>
</p>
<h2><a name="writing_your_own_debugger">Writing Your Own Debugger</a></h2>
<p>
</p>
<h3><a name="environment_variables">Environment Variables</a></h3>
<p>The <code>PERL5DB</code> environment variable can be used to define a debugger.
For example, the minimal ``working'' debugger (it actually doesn't do anything)
consists of one line:</p>
<pre>
  sub DB::DB {}</pre>
<p>It can easily be defined like this:</p>
<pre>
  $ PERL5DB=&quot;sub DB::DB {}&quot; perl -d your-script</pre>
<p>Another brief debugger, slightly more useful, can be created
with only the line:</p>
<pre>
  sub DB::DB {print ++$i; scalar &lt;STDIN&gt;}</pre>
<p>This debugger prints a number which increments for each statement
encountered and waits for you to hit a newline before continuing
to the next statement.</p>
<p>The following debugger is actually useful:</p>
<pre>
  {
    package DB;
    sub DB  {}
    sub sub {print ++$i, &quot; $sub\n&quot;; &amp;$sub}
  }</pre>
<p>It prints the sequence number of each subroutine call and the name of the
called subroutine.  Note that <code>&amp;DB::sub</code> is being compiled into the
package <code>DB</code> through the use of the <code>package</code> directive.</p>
<p>When it starts, the debugger reads your rc file (<em>./.perldb</em> or
<em>~/.perldb</em> under Unix), which can set important options.
(A subroutine (<code>&amp;afterinit</code>) can be defined here as well; it is executed
after the debugger completes its own initialization.)</p>
<p>After the rc file is read, the debugger reads the PERLDB_OPTS
environment variable and uses it to set debugger options. The
contents of this variable are treated as if they were the argument
of an <code>o ...</code> debugger command (q.v. in <a href="perldebug.html#options">Options in the perldebug manpage</a>).</p>
<p>
</p>
<h3><a name="debugger_internal_variables_in_addition_to_the_file_and_subroutinerelated_variables_mentioned_above__the_debugger_also_maintains_various_magical_internal_variables_">Debugger internal variables
In addition to the file and subroutine-related variables mentioned above,
the debugger also maintains various magical internal variables.</a></h3>
<ul>
<li>
<p><code>@DB::dbline</code> is an alias for <code>@{&quot;::_&lt;current_file&quot;}</code>, which
holds the lines of the currently-selected file (compiled by Perl), either
explicitly chosen with the debugger's <code>f</code> command, or implicitly by flow
of execution.</p>
<p>Values in this array are magical in numeric context: they compare
equal to zero only if the line is not breakable.</p>
</li>
<li>
<p><code>%DB::dbline</code>, is an alias for <code>%{&quot;::_&lt;current_file&quot;}</code>, which
contains breakpoints and actions keyed by line number in
the currently-selected file, either explicitly chosen with the
debugger's <code>f</code> command, or implicitly by flow of execution.</p>
<p>As previously noted, individual entries (as opposed to the whole hash)
are settable.  Perl only cares about Boolean true here, although
the values used by <em>perl5db.pl</em> have the form
<code>&quot;$break_condition\0$action&quot;</code>.</p>
</li>
</ul>
<p>
</p>
<h3><a name="debugger_customization_functions">Debugger customization functions</a></h3>
<p>Some functions are provided to simplify customization.</p>
<ul>
<li>
<p>See <a href="perldebug.html#options">Options in the perldebug manpage</a> for description of options parsed by
<code>DB::parse_options(string)</code> parses debugger options; see
<em>pperldebug/Options</em> for a description of options recognized.</p>
</li>
<li>
<p><code>DB::dump_trace(skip[,count])</code> skips the specified number of frames
and returns a list containing information about the calling frames (all
of them, if <code>count</code> is missing).  Each entry is reference to a hash
with keys <code>context</code> (either <code>.</code>, <code>$</code>, or <code>@</code>), <code>sub</code> (subroutine
name, or info about <code>eval</code>), <code>args</code> (<code>undef</code> or a reference to
an array), <code>file</code>, and <code>line</code>.</p>
</li>
<li>
<p><code>DB::print_trace(FH, skip[, count[, short]])</code> prints
formatted info about caller frames.  The last two functions may be
convenient as arguments to <code>&lt;</code>, <code>&lt;&lt;</code> commands.</p>
</li>
</ul>
<p>Note that any variables and functions that are not documented in
this manpages (or in <a href="perldebug.html">the perldebug manpage</a>) are considered for internal   
use only, and as such are subject to change without notice.</p>
<p>
</p>
<hr />
<h1><a name="frame_listing_output_examples">Frame Listing Output Examples</a></h1>
<p>The <code>frame</code> option can be used to control the output of frame 
information.  For example, contrast this expression trace:</p>
<pre>
 $ perl -de 42
 Stack dump during die enabled outside of evals.</pre>
<pre>
 Loading DB routines from perl5db.pl patch level 0.94
 Emacs support available.</pre>
<pre>
 Enter h or `h h' for help.</pre>
<pre>
 main::(-e:1):   0
   DB&lt;1&gt; sub foo { 14 }</pre>
<pre>
   DB&lt;2&gt; sub bar { 3 }</pre>
<pre>
   DB&lt;3&gt; t print foo() * bar()
 main::((eval 172):3):   print foo() + bar();
 main::foo((eval 168):2):
 main::bar((eval 170):2):
 42</pre>
<p>with this one, once the <code>o</code>ption <code>frame=2</code> has been set:</p>
<pre>
   DB&lt;4&gt; o f=2
                frame = '2'
   DB&lt;5&gt; t print foo() * bar()
 3:      foo() * bar()
 entering main::foo
  2:     sub foo { 14 };
 exited main::foo
 entering main::bar
  2:     sub bar { 3 };
 exited main::bar
 42</pre>
<p>By way of demonstration, we present below a laborious listing
resulting from setting your <code>PERLDB_OPTS</code> environment variable to
the value <code>f=n N</code>, and running <em>perl -d -V</em> from the command line.
Examples use various values of <code>n</code> are shown to give you a feel
for the difference between settings.  Long those it may be, this
is not a complete listing, but only excerpts.</p>
<ol>
<li>
<pre>
  entering main::BEGIN
   entering Config::BEGIN
    Package lib/Exporter.pm.
    Package lib/Carp.pm.
   Package lib/Config.pm.
   entering Config::TIEHASH
   entering Exporter::import
    entering Exporter::export
  entering Config::myconfig
   entering Config::FETCH
   entering Config::FETCH
   entering Config::FETCH
   entering Config::FETCH</pre>
<li>
<pre>
  entering main::BEGIN
   entering Config::BEGIN
    Package lib/Exporter.pm.
    Package lib/Carp.pm.
   exited Config::BEGIN
   Package lib/Config.pm.
   entering Config::TIEHASH
   exited Config::TIEHASH
   entering Exporter::import
    entering Exporter::export
    exited Exporter::export
   exited Exporter::import
  exited main::BEGIN
  entering Config::myconfig
   entering Config::FETCH
   exited Config::FETCH
   entering Config::FETCH
   exited Config::FETCH
   entering Config::FETCH</pre>
<li>
<pre>
  in  $=main::BEGIN() from /dev/null:0
   in  $=Config::BEGIN() from lib/Config.pm:2
    Package lib/Exporter.pm.
    Package lib/Carp.pm.
   Package lib/Config.pm.
   in  $=Config::TIEHASH('Config') from lib/Config.pm:644
   in  $=Exporter::import('Config', 'myconfig', 'config_vars') from /dev/null:0
    in  $=Exporter::export('Config', 'main', 'myconfig', 'config_vars') from li
  in  @=Config::myconfig() from /dev/null:0
   in  $=Config::FETCH(ref(Config), 'package') from lib/Config.pm:574
   in  $=Config::FETCH(ref(Config), 'baserev') from lib/Config.pm:574
   in  $=Config::FETCH(ref(Config), 'PERL_VERSION') from lib/Config.pm:574
   in  $=Config::FETCH(ref(Config), 'PERL_SUBVERSION') from lib/Config.pm:574
   in  $=Config::FETCH(ref(Config), 'osname') from lib/Config.pm:574
   in  $=Config::FETCH(ref(Config), 'osvers') from lib/Config.pm:574</pre>
<li>
<pre>
  in  $=main::BEGIN() from /dev/null:0
   in  $=Config::BEGIN() from lib/Config.pm:2
    Package lib/Exporter.pm.
    Package lib/Carp.pm.
   out $=Config::BEGIN() from lib/Config.pm:0
   Package lib/Config.pm.
   in  $=Config::TIEHASH('Config') from lib/Config.pm:644
   out $=Config::TIEHASH('Config') from lib/Config.pm:644
   in  $=Exporter::import('Config', 'myconfig', 'config_vars') from /dev/null:0
    in  $=Exporter::export('Config', 'main', 'myconfig', 'config_vars') from lib/
    out $=Exporter::export('Config', 'main', 'myconfig', 'config_vars') from lib/
   out $=Exporter::import('Config', 'myconfig', 'config_vars') from /dev/null:0
  out $=main::BEGIN() from /dev/null:0
  in  @=Config::myconfig() from /dev/null:0
   in  $=Config::FETCH(ref(Config), 'package') from lib/Config.pm:574
   out $=Config::FETCH(ref(Config), 'package') from lib/Config.pm:574
   in  $=Config::FETCH(ref(Config), 'baserev') from lib/Config.pm:574
   out $=Config::FETCH(ref(Config), 'baserev') from lib/Config.pm:574
   in  $=Config::FETCH(ref(Config), 'PERL_VERSION') from lib/Config.pm:574
   out $=Config::FETCH(ref(Config), 'PERL_VERSION') from lib/Config.pm:574
   in  $=Config::FETCH(ref(Config), 'PERL_SUBVERSION') from lib/Config.pm:574</pre>
<li>
<pre>
  in  $=main::BEGIN() from /dev/null:0
   in  $=Config::BEGIN() from lib/Config.pm:2
    Package lib/Exporter.pm.
    Package lib/Carp.pm.
   out $=Config::BEGIN() from lib/Config.pm:0
   Package lib/Config.pm.
   in  $=Config::TIEHASH('Config') from lib/Config.pm:644
   out $=Config::TIEHASH('Config') from lib/Config.pm:644
   in  $=Exporter::import('Config', 'myconfig', 'config_vars') from /dev/null:0
    in  $=Exporter::export('Config', 'main', 'myconfig', 'config_vars') from lib/E
    out $=Exporter::export('Config', 'main', 'myconfig', 'config_vars') from lib/E
   out $=Exporter::import('Config', 'myconfig', 'config_vars') from /dev/null:0
  out $=main::BEGIN() from /dev/null:0
  in  @=Config::myconfig() from /dev/null:0
   in  $=Config::FETCH('Config=HASH(0x1aa444)', 'package') from lib/Config.pm:574
   out $=Config::FETCH('Config=HASH(0x1aa444)', 'package') from lib/Config.pm:574
   in  $=Config::FETCH('Config=HASH(0x1aa444)', 'baserev') from lib/Config.pm:574
   out $=Config::FETCH('Config=HASH(0x1aa444)', 'baserev') from lib/Config.pm:574</pre>
<li>
<pre>
  in  $=CODE(0x15eca4)() from /dev/null:0
   in  $=CODE(0x182528)() from lib/Config.pm:2
    Package lib/Exporter.pm.
   out $=CODE(0x182528)() from lib/Config.pm:0
   scalar context return from CODE(0x182528): undef
   Package lib/Config.pm.
   in  $=Config::TIEHASH('Config') from lib/Config.pm:628
   out $=Config::TIEHASH('Config') from lib/Config.pm:628
   scalar context return from Config::TIEHASH:   empty hash
   in  $=Exporter::import('Config', 'myconfig', 'config_vars') from /dev/null:0
    in  $=Exporter::export('Config', 'main', 'myconfig', 'config_vars') from lib/Exporter.pm:171
    out $=Exporter::export('Config', 'main', 'myconfig', 'config_vars') from lib/Exporter.pm:171
    scalar context return from Exporter::export: ''
   out $=Exporter::import('Config', 'myconfig', 'config_vars') from /dev/null:0
   scalar context return from Exporter::import: ''</pre>
</ol>
<p>In all cases shown above, the line indentation shows the call tree.
If bit 2 of <code>frame</code> is set, a line is printed on exit from a
subroutine as well.  If bit 4 is set, the arguments are printed
along with the caller info.  If bit 8 is set, the arguments are
printed even if they are tied or references.  If bit 16 is set, the
return value is printed, too.</p>
<p>When a package is compiled, a line like this</p>
<pre>
    Package lib/Carp.pm.</pre>
<p>is printed with proper indentation.</p>
<p>
</p>
<hr />
<h1><a name="debugging_regular_expressions">Debugging regular expressions</a></h1>
<p>There are two ways to enable debugging output for regular expressions.</p>
<p>If your perl is compiled with <code>-DDEBUGGING</code>, you may use the
<strong>-Dr</strong> flag on the command line.</p>
<p>Otherwise, one can <code>use re 'debug'</code>, which has effects at
compile time and run time.  It is not lexically scoped.</p>
<p>
</p>
<h2><a name="compiletime_output">Compile-time output</a></h2>
<p>The debugging output at compile time looks like this:</p>
<pre>
  Compiling REx `[bc]d(ef*g)+h[ij]k$'
  size 45 Got 364 bytes for offset annotations.
  first at 1
  rarest char g at 0
  rarest char d at 0
     1: ANYOF[bc](12)
    12: EXACT &lt;d&gt;(14)
    14: CURLYX[0] {1,32767}(28)
    16:   OPEN1(18)
    18:     EXACT &lt;e&gt;(20)
    20:     STAR(23)
    21:       EXACT &lt;f&gt;(0)
    23:     EXACT &lt;g&gt;(25)
    25:   CLOSE1(27)
    27:   WHILEM[1/1](0)
    28: NOTHING(29)
    29: EXACT &lt;h&gt;(31)
    31: ANYOF[ij](42)
    42: EXACT &lt;k&gt;(44)
    44: EOL(45)
    45: END(0)
  anchored `de' at 1 floating `gh' at 3..2147483647 (checking floating) 
        stclass `ANYOF[bc]' minlen 7 
  Offsets: [45]
        1[4] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 5[1]
        0[0] 12[1] 0[0] 6[1] 0[0] 7[1] 0[0] 9[1] 8[1] 0[0] 10[1] 0[0]
        11[1] 0[0] 12[0] 12[0] 13[1] 0[0] 14[4] 0[0] 0[0] 0[0] 0[0]
        0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 18[1] 0[0] 19[1] 20[0]  
  Omitting $` $&amp; $' support.</pre>
<p>The first line shows the pre-compiled form of the regex.  The second
shows the size of the compiled form (in arbitrary units, usually
4-byte words) and the total number of bytes allocated for the
offset/length table, usually 4+<code>size</code>*8.  The next line shows the
label <em>id</em> of the first node that does a match.</p>
<p>The</p>
<pre>
  anchored `de' at 1 floating `gh' at 3..2147483647 (checking floating) 
        stclass `ANYOF[bc]' minlen 7</pre>
<p>line (split into two lines above) contains optimizer
information.  In the example shown, the optimizer found that the match 
should contain a substring <code>de</code> at offset 1, plus substring <code>gh</code>
at some offset between 3 and infinity.  Moreover, when checking for
these substrings (to abandon impossible matches quickly), Perl will check
for the substring <code>gh</code> before checking for the substring <code>de</code>.  The
optimizer may also use the knowledge that the match starts (at the
<code>first</code> <em>id</em>) with a character class, and no string 
shorter than 7 characters can possibly match.</p>
<p>The fields of interest which may appear in this line are</p>
<dl>
<dt><strong><a name="item_anchored_string_at_pos"><a href="#item_anchored"><code>anchored</code></a> <em>STRING</em> <code>at</code> <em>POS</em></a></strong>

<dt><strong><a name="item_floating_string_at_pos1_2e_2epos2"><code>floating</code> <em>STRING</em> <code>at</code> <em>POS1..POS2</em></a></strong>

<dd>
<p>See above.</p>
</dd>
</li>
<dt><strong><a name="item_matching_floating_2fanchored"><code>matching floating/anchored</code></a></strong>

<dd>
<p>Which substring to check first.</p>
</dd>
</li>
<dt><strong><a name="item_minlen"><code>minlen</code></a></strong>

<dd>
<p>The minimal length of the match.</p>
</dd>
</li>
<dt><strong><a name="item_stclass"><code>stclass</code> <em>TYPE</em></a></strong>

<dd>
<p>Type of first matching node.</p>
</dd>
</li>
<dt><strong><a name="item_noscan"><code>noscan</code></a></strong>

<dd>
<p>Don't scan for the found substrings.</p>
</dd>
</li>
<dt><strong><a name="item_isall"><code>isall</code></a></strong>

<dd>
<p>Means that the optimizer information is all that the regular
expression contains, and thus one does not need to enter the regex engine at
all.</p>
</dd>
</li>
<dt><strong><a name="item_gpos"><code>GPOS</code></a></strong>

<dd>
<p>Set if the pattern contains <code>\G</code>.</p>
</dd>
</li>
<dt><strong><a name="item_plus"><code>plus</code></a></strong>

<dd>
<p>Set if the pattern starts with a repeated char (as in <code>x+y</code>).</p>
</dd>
</li>
<dt><strong><a name="item_implicit"><code>implicit</code></a></strong>

<dd>
<p>Set if the pattern starts with <code>.*</code>.</p>
</dd>
</li>
<dt><strong><a name="item_with_eval"><code>with eval</code></a></strong>

<dd>
<p>Set if the pattern contain eval-groups, such as <code>(?{ code })</code> and
<code>(??{ code })</code>.</p>
</dd>
</li>
<dt><strong><a name="item_anchored"><code>anchored(TYPE)</code></a></strong>

<dd>
<p>If the pattern may match only at a handful of places, (with <code>TYPE</code>
being <code>BOL</code>, <code>MBOL</code>, or <a href="#item_gpos"><code>GPOS</code></a>.  See the table below.</p>
</dd>
</li>
</dl>
<p>If a substring is known to match at end-of-line only, it may be
followed by <code>$</code>, as in <code>floating `k'$</code>.</p>
<p>The optimizer-specific information is used to avoid entering (a slow) regex
engine on strings that will not definitely match.  If the <a href="#item_isall"><code>isall</code></a> flag
is set, a call to the regex engine may be avoided even when the optimizer
found an appropriate place for the match.</p>
<p>Above the optimizer section is the list of <em>nodes</em> of the compiled
form of the regex.  Each line has format</p>
<p><code>   </code><em>id</em>: <em>TYPE</em> <em>OPTIONAL-INFO</em> (<em>next-id</em>)</p>
<p>
</p>
<h2><a name="types_of_nodes">Types of nodes</a></h2>
<p>Here are the possible types, with short descriptions:</p>
<pre>
    # TYPE arg-description [num-args] [longjump-len] DESCRIPTION</pre>
<pre>
    # Exit points
    END         no      End of program.
    SUCCEED     no      Return from a subroutine, basically.</pre>
<pre>
    # Anchors:
    BOL         no      Match &quot;&quot; at beginning of line.
    MBOL        no      Same, assuming multiline.
    SBOL        no      Same, assuming singleline.
    EOS         no      Match &quot;&quot; at end of string.
    EOL         no      Match &quot;&quot; at end of line.
    MEOL        no      Same, assuming multiline.
    SEOL        no      Same, assuming singleline.
    BOUND       no      Match &quot;&quot; at any word boundary
    BOUNDL      no      Match &quot;&quot; at any word boundary
    NBOUND      no      Match &quot;&quot; at any word non-boundary
    NBOUNDL     no      Match &quot;&quot; at any word non-boundary
    GPOS        no      Matches where last m//g left off.</pre>
<pre>
    # [Special] alternatives
    ANY         no      Match any one character (except newline).
    SANY        no      Match any one character.
    ANYOF       sv      Match character in (or not in) this class.
    ALNUM       no      Match any alphanumeric character
    ALNUML      no      Match any alphanumeric char in locale
    NALNUM      no      Match any non-alphanumeric character
    NALNUML     no      Match any non-alphanumeric char in locale
    SPACE       no      Match any whitespace character
    SPACEL      no      Match any whitespace char in locale
    NSPACE      no      Match any non-whitespace character
    NSPACEL     no      Match any non-whitespace char in locale
    DIGIT       no      Match any numeric character
    NDIGIT      no      Match any non-numeric character</pre>
<pre>
    # BRANCH    The set of branches constituting a single choice are hooked
    #           together with their &quot;next&quot; pointers, since precedence prevents
    #           anything being concatenated to any individual branch.  The
    #           &quot;next&quot; pointer of the last BRANCH in a choice points to the
    #           thing following the whole choice.  This is also where the
    #           final &quot;next&quot; pointer of each individual branch points; each
    #           branch starts with the operand node of a BRANCH node.
    #
    BRANCH      node    Match this alternative, or the next...</pre>
<pre>
    # BACK      Normal &quot;next&quot; pointers all implicitly point forward; BACK
    #           exists to make loop structures possible.
    # not used
    BACK        no      Match &quot;&quot;, &quot;next&quot; ptr points backward.</pre>
<pre>
    # Literals
    EXACT       sv      Match this string (preceded by length).
    EXACTF      sv      Match this string, folded (prec. by length).
    EXACTFL     sv      Match this string, folded in locale (w/len).</pre>
<pre>
    # Do nothing
    NOTHING     no      Match empty string.
    # A variant of above which delimits a group, thus stops optimizations
    TAIL        no      Match empty string. Can jump here from outside.</pre>
<pre>
    # STAR,PLUS '?', and complex '*' and '+', are implemented as circular
    #           BRANCH structures using BACK.  Simple cases (one character
    #           per match) are implemented with STAR and PLUS for speed
    #           and to minimize recursive plunges.
    #
    STAR        node    Match this (simple) thing 0 or more times.
    PLUS        node    Match this (simple) thing 1 or more times.</pre>
<pre>
    CURLY       sv 2    Match this simple thing {n,m} times.
    CURLYN      no 2    Match next-after-this simple thing 
    #                   {n,m} times, set parens.
    CURLYM      no 2    Match this medium-complex thing {n,m} times.
    CURLYX      sv 2    Match this complex thing {n,m} times.</pre>
<pre>
    # This terminator creates a loop structure for CURLYX
    WHILEM      no      Do curly processing and see if rest matches.</pre>
<pre>
    # OPEN,CLOSE,GROUPP ...are numbered at compile time.
    OPEN        num 1   Mark this point in input as start of #n.
    CLOSE       num 1   Analogous to OPEN.</pre>
<pre>
    REF         num 1   Match some already matched string
    REFF        num 1   Match already matched string, folded
    REFFL       num 1   Match already matched string, folded in loc.</pre>
<pre>
    # grouping assertions
    IFMATCH     off 1 2 Succeeds if the following matches.
    UNLESSM     off 1 2 Fails if the following matches.
    SUSPEND     off 1 1 &quot;Independent&quot; sub-regex.
    IFTHEN      off 1 1 Switch, should be preceded by switcher .
    GROUPP      num 1   Whether the group matched.</pre>
<pre>
    # Support for long regex
    LONGJMP     off 1 1 Jump far away.
    BRANCHJ     off 1 1 BRANCH with long offset.</pre>
<pre>
    # The heavy worker
    EVAL        evl 1   Execute some Perl code.</pre>
<pre>
    # Modifiers
    MINMOD      no      Next operator is not greedy.
    LOGICAL     no      Next opcode should set the flag only.</pre>
<pre>
    # This is not used yet
    RENUM       off 1 1 Group with independently numbered parens.</pre>
<pre>
    # This is not really a node, but an optimized away piece of a &quot;long&quot; node.
    # To simplify debugging output, we mark it as if it were a node
    OPTIMIZED   off     Placeholder for dump.</pre>
<p>Following the optimizer information is a dump of the offset/length
table, here split across several lines:</p>
<pre>
  Offsets: [45]
        1[4] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 5[1]
        0[0] 12[1] 0[0] 6[1] 0[0] 7[1] 0[0] 9[1] 8[1] 0[0] 10[1] 0[0]
        11[1] 0[0] 12[0] 12[0] 13[1] 0[0] 14[4] 0[0] 0[0] 0[0] 0[0]
        0[0] 0[0] 0[0] 0[0] 0[0] 0[0] 18[1] 0[0] 19[1] 20[0]</pre>
<p>The first line here indicates that the offset/length table contains 45
entries.  Each entry is a pair of integers, denoted by <code>offset[length]</code>.
Entries are numbered starting with 1, so entry #1 here is <code>1[4]</code> and
entry #12 is <code>5[1]</code>.  <code>1[4]</code> indicates that the node labeled <code>1:</code>
(the <code>1: ANYOF[bc]</code>) begins at character position 1 in the
pre-compiled form of the regex, and has a length of 4 characters.
<code>5[1]</code> in position 12 
indicates that the node labeled <code>12:</code>
(the <code>12: EXACT &lt;d&gt;</code>) begins at character position 5 in the
pre-compiled form of the regex, and has a length of 1 character.
<code>12[1]</code> in position 14 
indicates that the node labeled <code>14:</code>
(the <code>14: CURLYX[0] {1,32767}</code>) begins at character position 12 in the
pre-compiled form of the regex, and has a length of 1 character---that
is, it corresponds to the <code>+</code> symbol in the precompiled regex.</p>
<p><code>0[0]</code> items indicate that there is no corresponding node.</p>
<p>
</p>
<h2><a name="runtime_output">Run-time output</a></h2>
<p>First of all, when doing a match, one may get no run-time output even
if debugging is enabled.  This means that the regex engine was never
entered and that all of the job was therefore done by the optimizer.</p>
<p>If the regex engine was entered, the output may look like this:</p>
<pre>
  Matching `[bc]d(ef*g)+h[ij]k$' against `abcdefg__gh__'
    Setting an EVAL scope, savestack=3
     2 &lt;ab&gt; &lt;cdefg__gh_&gt;    |  1: ANYOF
     3 &lt;abc&gt; &lt;defg__gh_&gt;    | 11: EXACT &lt;d&gt;
     4 &lt;abcd&gt; &lt;efg__gh_&gt;    | 13: CURLYX {1,32767}
     4 &lt;abcd&gt; &lt;efg__gh_&gt;    | 26:   WHILEM
                                0 out of 1..32767  cc=effff31c
     4 &lt;abcd&gt; &lt;efg__gh_&gt;    | 15:     OPEN1
     4 &lt;abcd&gt; &lt;efg__gh_&gt;    | 17:     EXACT &lt;e&gt;
     5 &lt;abcde&gt; &lt;fg__gh_&gt;    | 19:     STAR
                             EXACT &lt;f&gt; can match 1 times out of 32767...
    Setting an EVAL scope, savestack=3
     6 &lt;bcdef&gt; &lt;g__gh__&gt;    | 22:       EXACT &lt;g&gt;
     7 &lt;bcdefg&gt; &lt;__gh__&gt;    | 24:       CLOSE1
     7 &lt;bcdefg&gt; &lt;__gh__&gt;    | 26:       WHILEM
                                    1 out of 1..32767  cc=effff31c
    Setting an EVAL scope, savestack=12
     7 &lt;bcdefg&gt; &lt;__gh__&gt;    | 15:         OPEN1
     7 &lt;bcdefg&gt; &lt;__gh__&gt;    | 17:         EXACT &lt;e&gt;
       restoring \1 to 4(4)..7
                                    failed, try continuation...
     7 &lt;bcdefg&gt; &lt;__gh__&gt;    | 27:         NOTHING
     7 &lt;bcdefg&gt; &lt;__gh__&gt;    | 28:         EXACT &lt;h&gt;
                                    failed...
                                failed...</pre>
<p>The most significant information in the output is about the particular <em>node</em>
of the compiled regex that is currently being tested against the target string.
The format of these lines is</p>
<p><code>    </code><em>STRING-OFFSET</em> &lt;<em>PRE-STRING</em>&gt; &lt;<em>POST-STRING</em>&gt;   |<em>ID</em>:  <em>TYPE</em></p>
<p>The <em>TYPE</em> info is indented with respect to the backtracking level.
Other incidental information appears interspersed within.</p>
<p>
</p>
<hr />
<h1><a name="debugging_perl_memory_usage">Debugging Perl memory usage</a></h1>
<p>Perl is a profligate wastrel when it comes to memory use.  There
is a saying that to estimate memory usage of Perl, assume a reasonable
algorithm for memory allocation, multiply that estimate by 10, and
while you still may miss the mark, at least you won't be quite so
astonished.  This is not absolutely true, but may provide a good
grasp of what happens.</p>
<p>Assume that an integer cannot take less than 20 bytes of memory, a
float cannot take less than 24 bytes, a string cannot take less
than 32 bytes (all these examples assume 32-bit architectures, the
result are quite a bit worse on 64-bit architectures).  If a variable
is accessed in two of three different ways (which require an integer,
a float, or a string), the memory footprint may increase yet another
20 bytes.  A sloppy <code>malloc(3)</code> implementation can inflate these
numbers dramatically.</p>
<p>On the opposite end of the scale, a declaration like</p>
<pre>
  sub foo;</pre>
<p>may take up to 500 bytes of memory, depending on which release of Perl
you're running.</p>
<p>Anecdotal estimates of source-to-compiled code bloat suggest an
eightfold increase.  This means that the compiled form of reasonable
(normally commented, properly indented etc.) code will take
about eight times more space in memory than the code took
on disk.</p>
<p>The <strong>-DL</strong> command-line switch is obsolete since circa Perl 5.6.0
(it was available only if Perl was built with <code>-DDEBUGGING</code>).
The switch was used to track Perl's memory allocations and possible
memory leaks.  These days the use of malloc debugging tools like
<em>Purify</em> or <em>valgrind</em> is suggested instead.</p>
<p>One way to find out how much memory is being used by Perl data
structures is to install the Devel::Size module from CPAN: it gives
you the minimum number of bytes required to store a particular data
structure.  Please be mindful of the difference between the <code>size()</code>
and total_size().</p>
<p>If Perl has been compiled using Perl's malloc you can analyze Perl
memory usage by setting the $ENV{PERL_DEBUG_MSTATS}.</p>
<p>
</p>
<h2><a name="using__env_perl_debug_mstats_">Using <code>$ENV{PERL_DEBUG_MSTATS}</code></a></h2>
<p>If your perl is using Perl's <code>malloc()</code> and was compiled with the
necessary switches (this is the default), then it will print memory
usage statistics after compiling your code when <code>$ENV{PERL_DEBUG_MSTATS}
&gt; 1</code>, and before termination of the program when <code>&lt;
$ENV{PERL_DEBUG_MSTATS} </code>= 1 &gt;&gt;.  The report format is similar to
the following example:</p>
<pre>
  $ PERL_DEBUG_MSTATS=2 perl -e &quot;require Carp&quot;
  Memory allocation statistics after compilation: (buckets 4(4)..8188(8192)
     14216 free:   130   117    28     7     9   0   2     2   1 0 0
                437    61    36     0     5
     60924 used:   125   137   161    55     7   8   6    16   2 0 1
                 74   109   304    84    20
  Total sbrk(): 77824/21:119. Odd ends: pad+heads+chain+tail: 0+636+0+2048.
  Memory allocation statistics after execution:   (buckets 4(4)..8188(8192)
     30888 free:   245    78    85    13     6   2   1     3   2 0 1
                315   162    39    42    11
    175816 used:   265   176  1112   111    26  22  11    27   2 1 1
                196   178  1066   798    39
  Total sbrk(): 215040/47:145. Odd ends: pad+heads+chain+tail: 0+2192+0+6144.</pre>
<p>It is possible to ask for such a statistic at arbitrary points in
your execution using the <code>mstat()</code> function out of the standard
Devel::Peek module.</p>
<p>Here is some explanation of that format:</p>
<dl>
<dt><strong><a name="item_smallest"><code>buckets SMALLEST(APPROX)..GREATEST(APPROX)</code></a></strong>

<dd>
<p>Perl's <code>malloc()</code> uses bucketed allocations.  Every request is rounded
up to the closest bucket size available, and a bucket is taken from
the pool of buckets of that size.</p>
</dd>
<dd>
<p>The line above describes the limits of buckets currently in use.
Each bucket has two sizes: memory footprint and the maximal size
of user data that can fit into this bucket.  Suppose in the above
example that the smallest bucket were size 4.  The biggest bucket
would have usable size 8188, and the memory footprint would be 8192.</p>
</dd>
<dd>
<p>In a Perl built for debugging, some buckets may have negative usable
size.  This means that these buckets cannot (and will not) be used.
For larger buckets, the memory footprint may be one page greater
than a power of 2.  If so, case the corresponding power of two is
printed in the <code>APPROX</code> field above.</p>
</dd>
</li>
<dt><strong><a name="item_free_2fused">Free/Used</a></strong>

<dd>
<p>The 1 or 2 rows of numbers following that correspond to the number
of buckets of each size between <a href="#item_smallest"><code>SMALLEST</code></a> and <code>GREATEST</code>.  In
the first row, the sizes (memory footprints) of buckets are powers
of two--or possibly one page greater.  In the second row, if present,
the memory footprints of the buckets are between the memory footprints
of two buckets ``above''.</p>
</dd>
<dd>
<p>For example, suppose under the previous example, the memory footprints
were</p>
</dd>
<dd>
<pre>
     free:    8     16    32    64    128  256 512 1024 2048 4096 8192
           4     12    24    48    80</pre>
</dd>
<dd>
<p>With non-<code>DEBUGGING</code> perl, the buckets starting from <code>128</code> have
a 4-byte overhead, and thus an 8192-long bucket may take up to
8188-byte allocations.</p>
</dd>
</li>
<dt><strong><a name="item_sbrk"><code>Total sbrk(): SBRKed/SBRKs:CONTINUOUS</code></a></strong>

<dd>
<p>The first two fields give the total amount of memory perl sbrk(2)ed
(ess-broken? :-) and number of sbrk(2)s used.  The third number is
what perl thinks about continuity of returned chunks.  So long as
this number is positive, <code>malloc()</code> will assume that it is probable
that <a href="#item_sbrk"><code>sbrk(2)</code></a> will provide continuous memory.</p>
</dd>
<dd>
<p>Memory allocated by external libraries is not counted.</p>
</dd>
</li>
<dt><strong><a name="item_pad_3a_0"><code>pad: 0</code></a></strong>

<dd>
<p>The amount of sbrk(2)ed memory needed to keep buckets aligned.</p>
</dd>
</li>
<dt><strong><a name="item_heads_3a_2192"><code>heads: 2192</code></a></strong>

<dd>
<p>Although memory overhead of bigger buckets is kept inside the bucket, for
smaller buckets, it is kept in separate areas.  This field gives the
total size of these areas.</p>
</dd>
</li>
<dt><strong><a name="item_chain_3a_0"><code>chain: 0</code></a></strong>

<dd>
<p><code>malloc()</code> may want to subdivide a bigger bucket into smaller buckets.
If only a part of the deceased bucket is left unsubdivided, the rest
is kept as an element of a linked list.  This field gives the total
size of these chunks.</p>
</dd>
</li>
<dt><strong><a name="item_tail_3a_6144"><code>tail: 6144</code></a></strong>

<dd>
<p>To minimize the number of sbrk(2)s, <code>malloc()</code> asks for more memory.  This
field gives the size of the yet unused part, which is sbrk(2)ed, but
never touched.</p>
</dd>
</li>
</dl>
<p>
</p>
<hr />
<h1><a name="see_also">SEE ALSO</a></h1>
<p><a href="perldebug.html">the perldebug manpage</a>,
<a href="perlguts.html">the perlguts manpage</a>,
<a href="perlrun.html">the perlrun manpage</a>
<a href="../../re.html">the re manpage</a>,
and
<a href="../../Devel/DProf.html">the Devel::DProf manpage</a>.</p>
<table border="0" width="100%" cellspacing="0" cellpadding="3">
<tr><td class="block" style="background-color: #cccccc" valign="middle">
<big><strong><span class="block">&nbsp;perldebguts - Guts of Perl debugging</span></strong></big>
</td></tr>
</table>

</body>

</html>
