<?xml version="1.0" ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>perlpacktut - tutorial on C&lt;pack&gt; and C&lt;unpack&gt;</title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rev="made" href="mailto:root@localhost" />
</head>

<body style="background-color: white">
<table border="0" width="100%" cellspacing="0" cellpadding="3">
<tr><td class="block" style="background-color: #cccccc" valign="middle">
<big><strong><span class="block">&nbsp;perlpacktut - tutorial on C&lt;pack&gt; and C&lt;unpack&gt;</span></strong></big>
</td></tr>
</table>

<p><a name="__index__"></a></p>
<!-- INDEX BEGIN -->

<ul>

	<li><a href="#name">NAME</a></li>
	<li><a href="#description">DESCRIPTION</a></li>
	<li><a href="#the_basic_principle">The Basic Principle</a></li>
	<li><a href="#packing_text">Packing Text</a></li>
	<li><a href="#packing_numbers">Packing Numbers</a></li>
	<ul>

		<li><a href="#integers">Integers</a></li>
		<li><a href="#unpacking_a_stack_frame">Unpacking a Stack Frame</a></li>
		<li><a href="#how_to_eat_an_egg_on_a_net">How to Eat an Egg on a Net</a></li>
		<li><a href="#floating_point_numbers">Floating point Numbers</a></li>
	</ul>

	<li><a href="#exotic_templates">Exotic Templates</a></li>
	<ul>

		<li><a href="#bit_strings">Bit Strings</a></li>
		<li><a href="#uuencoding">Uuencoding</a></li>
		<li><a href="#doing_sums">Doing Sums</a></li>
		<li><a href="#unicode">Unicode</a></li>
		<li><a href="#another_portable_binary_encoding">Another Portable Binary Encoding</a></li>
	</ul>

	<li><a href="#template_grouping">Template Grouping</a></li>
	<li><a href="#lengths_and_widths">Lengths and Widths</a></li>
	<ul>

		<li><a href="#string_lengths">String Lengths</a></li>
		<li><a href="#dynamic_templates">Dynamic Templates</a></li>
		<li><a href="#counting_repetitions">Counting Repetitions</a></li>
	</ul>

	<li><a href="#packing_and_unpacking_c_structures">Packing and Unpacking C Structures</a></li>
	<ul>

		<li><a href="#the_alignment_pit">The Alignment Pit</a></li>
		<li><a href="#alignment__take_2">Alignment, Take 2</a></li>
		<li><a href="#alignment__take_3">Alignment, Take 3</a></li>
		<li><a href="#pointers_for_how_to_use_them">Pointers for How to Use Them</a></li>
	</ul>

	<li><a href="#pack_recipes">Pack Recipes</a></li>
	<li><a href="#funnies_section">Funnies Section</a></li>
	<li><a href="#authors">Authors</a></li>
</ul>
<!-- INDEX END -->

<hr />
<p>
</p>
<h1><a name="name">NAME</a></h1>
<p>perlpacktut - tutorial on <code>pack</code> and <code>unpack</code></p>
<p>
</p>
<hr />
<h1><a name="description">DESCRIPTION</a></h1>
<p><code>pack</code> and <code>unpack</code> are two functions for transforming data according
to a user-defined template, between the guarded way Perl stores values
and some well-defined representation as might be required in the 
environment of a Perl program. Unfortunately, they're also two of 
the most misunderstood and most often overlooked functions that Perl
provides. This tutorial will demystify them for you.</p>
<p>
</p>
<hr />
<h1><a name="the_basic_principle">The Basic Principle</a></h1>
<p>Most programming languages don't shelter the memory where variables are
stored. In C, for instance, you can take the address of some variable,
and the <code>sizeof</code> operator tells you how many bytes are allocated to
the variable. Using the address and the size, you may access the storage
to your heart's content.</p>
<p>In Perl, you just can't access memory at random, but the structural and
representational conversion provided by <code>pack</code> and <code>unpack</code> is an
excellent alternative. The <code>pack</code> function converts values to a byte
sequence containing representations according to a given specification,
the so-called ``template'' argument. <code>unpack</code> is the reverse process,
deriving some values from the contents of a string of bytes. (Be cautioned,
however, that not all that has been packed together can be neatly unpacked - 
a very common experience as seasoned travellers are likely to confirm.)</p>
<p>Why, you may ask, would you need a chunk of memory containing some values
in binary representation? One good reason is input and output accessing
some file, a device, or a network connection, whereby this binary
representation is either forced on you or will give you some benefit
in processing. Another cause is passing data to some system call that
is not available as a Perl function: <code>syscall</code> requires you to provide
parameters stored in the way it happens in a C program. Even text processing 
(as shown in the next section) may be simplified with judicious usage 
of these two functions.</p>
<p>To see how (un)packing works, we'll start with a simple template
code where the conversion is in low gear: between the contents of a byte
sequence and a string of hexadecimal digits. Let's use <code>unpack</code>, since
this is likely to remind you of a dump program, or some desperate last
message unfortunate programs are wont to throw at you before they expire
into the wild blue yonder. Assuming that the variable <code>$mem</code> holds a 
sequence of bytes that we'd like to inspect without assuming anything 
about its meaning, we can write</p>
<pre>
   my( $hex ) = unpack( 'H*', $mem );
   print &quot;$hex\n&quot;;</pre>
<p>whereupon we might see something like this, with each pair of hex digits
corresponding to a byte:</p>
<pre>
   41204d414e204120504c414e20412043414e414c2050414e414d41</pre>
<p>What was in this chunk of memory? Numbers, characters, or a mixture of
both? Assuming that we're on a computer where ASCII (or some similar)
encoding is used: hexadecimal values in the range <code>0x40</code> - <code>0x5A</code>
indicate an uppercase letter, and <code>0x20</code> encodes a space. So we might
assume it is a piece of text, which some are able to read like a tabloid;
but others will have to get hold of an ASCII table and relive that
firstgrader feeling. Not caring too much about which way to read this,
we note that <code>unpack</code> with the template code <code>H</code> converts the contents
of a sequence of bytes into the customary hexadecimal notation. Since
``a sequence of'' is a pretty vague indication of quantity, <code>H</code> has been
defined to convert just a single hexadecimal digit unless it is followed
by a repeat count. An asterisk for the repeat count means to use whatever
remains.</p>
<p>The inverse operation - packing byte contents from a string of hexadecimal
digits - is just as easily written. For instance:</p>
<pre>
   my $s = pack( 'H2' x 10, map { &quot;3$_&quot; } ( 0..9 ) );
   print &quot;$s\n&quot;;</pre>
<p>Since we feed a list of ten 2-digit hexadecimal strings to <code>pack</code>, the
pack template should contain ten pack codes. If this is run on a computer
with ASCII character coding, it will print <code>0123456789</code>.</p>
<p>
</p>
<hr />
<h1><a name="packing_text">Packing Text</a></h1>
<p>Let's suppose you've got to read in a data file like this:</p>
<pre>
    Date      |Description                | Income|Expenditure
    01/24/2001 Ahmed's Camel Emporium                  1147.99
    01/28/2001 Flea spray                                24.99
    01/29/2001 Camel rides to tourists      235.00</pre>
<p>How do we do it? You might think first to use <code>split</code>; however, since
<code>split</code> collapses blank fields, you'll never know whether a record was
income or expenditure. Oops. Well, you could always use <code>substr</code>:</p>
<pre>
    while (&lt;&gt;) { 
        my $date   = substr($_,  0, 11);
        my $desc   = substr($_, 12, 27);
        my $income = substr($_, 40,  7);
        my $expend = substr($_, 52,  7);
        ...
    }</pre>
<p>It's not really a barrel of laughs, is it? In fact, it's worse than it
may seem; the eagle-eyed may notice that the first field should only be
10 characters wide, and the error has propagated right through the other
numbers - which we've had to count by hand. So it's error-prone as well
as horribly unfriendly.</p>
<p>Or maybe we could use regular expressions:</p>
<pre>
    while (&lt;&gt;) { 
        my($date, $desc, $income, $expend) = 
            m|(\d\d/\d\d/\d{4}) (.{27}) (.{7})(.*)|;
        ...
    }</pre>
<p>Urgh. Well, it's a bit better, but - well, would you want to maintain
that?</p>
<p>Hey, isn't Perl supposed to make this sort of thing easy? Well, it does,
if you use the right tools. <code>pack</code> and <code>unpack</code> are designed to help
you out when dealing with fixed-width data like the above. Let's have a
look at a solution with <code>unpack</code>:</p>
<pre>
    while (&lt;&gt;) { 
        my($date, $desc, $income, $expend) = unpack(&quot;A10xA27xA7A*&quot;, $_);
        ...
    }</pre>
<p>That looks a bit nicer; but we've got to take apart that weird template.
Where did I pull that out of?</p>
<p>OK, let's have a look at some of our data again; in fact, we'll include
the headers, and a handy ruler so we can keep track of where we are.</p>
<pre>
             1         2         3         4         5        
    1234567890123456789012345678901234567890123456789012345678
    Date      |Description                | Income|Expenditure
    01/28/2001 Flea spray                                24.99
    01/29/2001 Camel rides to tourists      235.00</pre>
<p>From this, we can see that the date column stretches from column 1 to
column 10 - ten characters wide. The <code>pack</code>-ese for ``character'' is
<code>A</code>, and ten of them are <code>A10</code>. So if we just wanted to extract the
dates, we could say this:</p>
<pre>
    my($date) = unpack(&quot;A10&quot;, $_);</pre>
<p>OK, what's next? Between the date and the description is a blank column;
we want to skip over that. The <code>x</code> template means ``skip forward'', so we
want one of those. Next, we have another batch of characters, from 12 to
38. That's 27 more characters, hence <code>A27</code>. (Don't make the fencepost
error - there are 27 characters between 12 and 38, not 26. Count 'em!)</p>
<p>Now we skip another character and pick up the next 7 characters:</p>
<pre>
    my($date,$description,$income) = unpack(&quot;A10xA27xA7&quot;, $_);</pre>
<p>Now comes the clever bit. Lines in our ledger which are just income and
not expenditure might end at column 46. Hence, we don't want to tell our
<code>unpack</code> pattern that we <strong>need</strong> to find another 12 characters; we'll
just say ``if there's anything left, take it''. As you might guess from
regular expressions, that's what the <code>*</code> means: ``use everything
remaining''.</p>
<ul>
<li>
<p>Be warned, though, that unlike regular expressions, if the <code>unpack</code>
template doesn't match the incoming data, Perl will scream and die.</p>
</li>
</ul>
<p>Hence, putting it all together:</p>
<pre>
    my($date,$description,$income,$expend) = unpack(&quot;A10xA27xA7xA*&quot;, $_);</pre>
<p>Now, that's our data parsed. I suppose what we might want to do now is
total up our income and expenditure, and add another line to the end of
our ledger - in the same format - saying how much we've brought in and
how much we've spent:</p>
<pre>
    while (&lt;&gt;) {
        my($date, $desc, $income, $expend) = unpack(&quot;A10xA27xA7xA*&quot;, $_);
        $tot_income += $income;
        $tot_expend += $expend;
    }</pre>
<pre>
    $tot_income = sprintf(&quot;%.2f&quot;, $tot_income); # Get them into 
    $tot_expend = sprintf(&quot;%.2f&quot;, $tot_expend); # &quot;financial&quot; format</pre>
<pre>
    $date = POSIX::strftime(&quot;%m/%d/%Y&quot;, localtime);</pre>
<pre>
    # OK, let's go:</pre>
<pre>
    print pack(&quot;A10xA27xA7xA*&quot;, $date, &quot;Totals&quot;, $tot_income, $tot_expend);</pre>
<p>Oh, hmm. That didn't quite work. Let's see what happened:</p>
<pre>
    01/24/2001 Ahmed's Camel Emporium                   1147.99
    01/28/2001 Flea spray                                 24.99
    01/29/2001 Camel rides to tourists     1235.00
    03/23/2001Totals                     1235.001172.98</pre>
<p>OK, it's a start, but what happened to the spaces? We put <code>x</code>, didn't
we? Shouldn't it skip forward? Let's look at what <a href="perlfunc.html#pack">pack in the perlfunc manpage</a> says:</p>
<pre>
    x   A null byte.</pre>
<p>Urgh. No wonder. There's a big difference between ``a null byte'',
character zero, and ``a space'', character 32. Perl's put something
between the date and the description - but unfortunately, we can't see
it!</p>
<p>What we actually need to do is expand the width of the fields. The <code>A</code>
format pads any non-existent characters with spaces, so we can use the
additional spaces to line up our fields, like this:</p>
<pre>
    print pack(&quot;A11 A28 A8 A*&quot;, $date, &quot;Totals&quot;, $tot_income, $tot_expend);</pre>
<p>(Note that you can put spaces in the template to make it more readable,
but they don't translate to spaces in the output.) Here's what we got
this time:</p>
<pre>
    01/24/2001 Ahmed's Camel Emporium                   1147.99
    01/28/2001 Flea spray                                 24.99
    01/29/2001 Camel rides to tourists     1235.00
    03/23/2001 Totals                      1235.00 1172.98</pre>
<p>That's a bit better, but we still have that last column which needs to
be moved further over. There's an easy way to fix this up:
unfortunately, we can't get <code>pack</code> to right-justify our fields, but we
can get <code>sprintf</code> to do it:</p>
<pre>
    $tot_income = sprintf(&quot;%.2f&quot;, $tot_income); 
    $tot_expend = sprintf(&quot;%12.2f&quot;, $tot_expend);
    $date = POSIX::strftime(&quot;%m/%d/%Y&quot;, localtime); 
    print pack(&quot;A11 A28 A8 A*&quot;, $date, &quot;Totals&quot;, $tot_income, $tot_expend);</pre>
<p>This time we get the right answer:</p>
<pre>
    01/28/2001 Flea spray                                 24.99
    01/29/2001 Camel rides to tourists     1235.00
    03/23/2001 Totals                      1235.00      1172.98</pre>
<p>So that's how we consume and produce fixed-width data. Let's recap what
we've seen of <code>pack</code> and <code>unpack</code> so far:</p>
<ul>
<li>
<p>Use <code>pack</code> to go from several pieces of data to one fixed-width
version; use <code>unpack</code> to turn a fixed-width-format string into several
pieces of data.</p>
</li>
<li>
<p>The pack format <code>A</code> means ``any character''; if you're <code>pack</code>ing and
you've run out of things to pack, <code>pack</code> will fill the rest up with
spaces.</p>
</li>
<li>
<p><code>x</code> means ``skip a byte'' when <code>unpack</code>ing; when <code>pack</code>ing, it means
``introduce a null byte'' - that's probably not what you mean if you're
dealing with plain text.</p>
</li>
<li>
<p>You can follow the formats with numbers to say how many characters
should be affected by that format: <code>A12</code> means ``take 12 characters'';
<code>x6</code> means ``skip 6 bytes'' or ``character 0, 6 times''.</p>
</li>
<li>
<p>Instead of a number, you can use <code>*</code> to mean ``consume everything else
left''.</p>
<p><strong>Warning</strong>: when packing multiple pieces of data, <code>*</code> only means
``consume all of the current piece of data''. That's to say</p>
<pre>
    pack(&quot;A*A*&quot;, $one, $two)</pre>
<p>packs all of <code>$one</code> into the first <code>A*</code> and then all of <code>$two</code> into
the second. This is a general principle: each format character
corresponds to one piece of data to be <code>pack</code>ed.</p>
</li>
</ul>
<p>
</p>
<hr />
<h1><a name="packing_numbers">Packing Numbers</a></h1>
<p>So much for textual data. Let's get onto the meaty stuff that <code>pack</code>
and <code>unpack</code> are best at: handling binary formats for numbers. There is,
of course, not just one binary format  - life would be too simple - but
Perl will do all the finicky labor for you.</p>
<p>
</p>
<h2><a name="integers">Integers</a></h2>
<p>Packing and unpacking numbers implies conversion to and from some
<em>specific</em> binary representation. Leaving floating point numbers
aside for the moment, the salient properties of any such representation
are:</p>
<ul>
<li>
<p>the number of bytes used for storing the integer,</p>
</li>
<li>
<p>whether the contents are interpreted as a signed or unsigned number,</p>
</li>
<li>
<p>the byte ordering: whether the first byte is the least or most
significant byte (or: little-endian or big-endian, respectively).</p>
</li>
</ul>
<p>So, for instance, to pack 20302 to a signed 16 bit integer in your
computer's representation you write</p>
<pre>
   my $ps = pack( 's', 20302 );</pre>
<p>Again, the result is a string, now containing 2 bytes. If you print 
this string (which is, generally, not recommended) you might see
<code>ON</code> or <code>NO</code> (depending on your system's byte ordering) - or something
entirely different if your computer doesn't use ASCII character encoding.
Unpacking <code>$ps</code> with the same template returns the original integer value:</p>
<pre>
   my( $s ) = unpack( 's', $ps );</pre>
<p>This is true for all numeric template codes. But don't expect miracles:
if the packed value exceeds the allotted byte capacity, high order bits
are silently discarded, and unpack certainly won't be able to pull them
back out of some magic hat. And, when you pack using a signed template
code such as <code>s</code>, an excess value may result in the sign bit
getting set, and unpacking this will smartly return a negative value.</p>
<p>16 bits won't get you too far with integers, but there is <code>l</code> and <code>L</code>
for signed and unsigned 32-bit integers. And if this is not enough and
your system supports 64 bit integers you can push the limits much closer
to infinity with pack codes <code>q</code> and <code>Q</code>. A notable exception is provided
by pack codes <code>i</code> and <code>I</code> for signed and unsigned integers of the 
``local custom'' variety: Such an integer will take up as many bytes as
a local C compiler returns for <code>sizeof(int)</code>, but it'll use <em>at least</em>
32 bits.</p>
<p>Each of the integer pack codes <code>sSlLqQ</code> results in a fixed number of bytes,
no matter where you execute your program. This may be useful for some 
applications, but it does not provide for a portable way to pass data 
structures between Perl and C programs (bound to happen when you call 
XS extensions or the Perl function <code>syscall</code>), or when you read or
write binary files. What you'll need in this case are template codes that
depend on what your local C compiler compiles when you code <code>short</code> or
<code>unsigned long</code>, for instance. These codes and their corresponding
byte lengths are shown in the table below.  Since the C standard leaves
much leeway with respect to the relative sizes of these data types, actual
values may vary, and that's why the values are given as expressions in
C and Perl. (If you'd like to use values from <code>%Config</code> in your program
you have to import it with <code>use Config</code>.)</p>
<pre>
   signed unsigned  byte length in C   byte length in Perl       
     s!     S!      sizeof(short)      $Config{shortsize}
     i!     I!      sizeof(int)        $Config{intsize}
     l!     L!      sizeof(long)       $Config{longsize}
     q!     Q!      sizeof(long long)  $Config{longlongsize}</pre>
<p>The <code>i!</code> and <code>I!</code> codes aren't different from <code>i</code> and <code>I</code>; they are
tolerated for completeness' sake.</p>
<p>
</p>
<h2><a name="unpacking_a_stack_frame">Unpacking a Stack Frame</a></h2>
<p>Requesting a particular byte ordering may be necessary when you work with
binary data coming from some specific architecture whereas your program could
run on a totally different system. As an example, assume you have 24 bytes
containing a stack frame as it happens on an Intel 8086:</p>
<pre>
      +---------+        +----+----+               +---------+
 TOS: |   IP    |  TOS+4:| FL | FH | FLAGS  TOS+14:|   SI    |
      +---------+        +----+----+               +---------+
      |   CS    |        | AL | AH | AX            |   DI    |
      +---------+        +----+----+               +---------+
                         | BL | BH | BX            |   BP    |
                         +----+----+               +---------+
                         | CL | CH | CX            |   DS    |
                         +----+----+               +---------+
                         | DL | DH | DX            |   ES    |
                         +----+----+               +---------+</pre>
<p>First, we note that this time-honored 16-bit CPU uses little-endian order,
and that's why the low order byte is stored at the lower address. To
unpack such a (signed) short we'll have to use code <code>v</code>. A repeat
count unpacks all 12 shorts:</p>
<pre>
   my( $ip, $cs, $flags, $ax, $bx, $cd, $dx, $si, $di, $bp, $ds, $es ) =
     unpack( 'v12', $frame );</pre>
<p>Alternatively, we could have used <code>C</code> to unpack the individually
accessible byte registers FL, FH, AL, AH, etc.:</p>
<pre>
   my( $fl, $fh, $al, $ah, $bl, $bh, $cl, $ch, $dl, $dh ) =
     unpack( 'C10', substr( $frame, 4, 10 ) );</pre>
<p>It would be nice if we could do this in one fell swoop: unpack a short,
back up a little, and then unpack 2 bytes. Since Perl <em>is</em> nice, it
proffers the template code <code>X</code> to back up one byte. Putting this all
together, we may now write:</p>
<pre>
   my( $ip, $cs,
       $flags,$fl,$fh,
       $ax,$al,$ah, $bx,$bl,$bh, $cx,$cl,$ch, $dx,$dl,$dh, 
       $si, $di, $bp, $ds, $es ) =
   unpack( 'v2' . ('vXXCC' x 5) . 'v5', $frame );</pre>
<p>(The clumsy construction of the template can be avoided - just read on!)</p>
<p>We've taken some pains to construct the template so that it matches
the contents of our frame buffer. Otherwise we'd either get undefined values,
or <code>unpack</code> could not unpack all. If <code>pack</code> runs out of items, it will
supply null strings (which are coerced into zeroes whenever the pack code
says so).</p>
<p>
</p>
<h2><a name="how_to_eat_an_egg_on_a_net">How to Eat an Egg on a Net</a></h2>
<p>The pack code for big-endian (high order byte at the lowest address) is
<code>n</code> for 16 bit and <code>N</code> for 32 bit integers. You use these codes
if you know that your data comes from a compliant architecture, but,
surprisingly enough, you should also use these pack codes if you
exchange binary data, across the network, with some system that you
know next to nothing about. The simple reason is that this
order has been chosen as the <em>network order</em>, and all standard-fearing
programs ought to follow this convention. (This is, of course, a stern
backing for one of the Lilliputian parties and may well influence the
political development there.) So, if the protocol expects you to send
a message by sending the length first, followed by just so many bytes,
you could write:</p>
<pre>
   my $buf = pack( 'N', length( $msg ) ) . $msg;</pre>
<p>or even:</p>
<pre>
   my $buf = pack( 'NA*', length( $msg ), $msg );</pre>
<p>and pass <code>$buf</code> to your send routine. Some protocols demand that the
count should include the length of the count itself: then just add 4
to the data length. (But make sure to read <a href="#lengths_and_widths">Lengths and Widths</a> before
you really code this!)</p>
<p>
</p>
<h2><a name="floating_point_numbers">Floating point Numbers</a></h2>
<p>For packing floating point numbers you have the choice between the
pack codes <code>f</code> and <code>d</code> which pack into (or unpack from) single-precision or
double-precision representation as it is provided by your system. (There
is no such thing as a network representation for reals, so if you want
to send your real numbers across computer boundaries, you'd better stick
to ASCII representation, unless you're absolutely sure what's on the other
end of the line.)</p>
<p>
</p>
<hr />
<h1><a name="exotic_templates">Exotic Templates</a></h1>
<p>
</p>
<h2><a name="bit_strings">Bit Strings</a></h2>
<p>Bits are the atoms in the memory world. Access to individual bits may
have to be used either as a last resort or because it is the most
convenient way to handle your data. Bit string (un)packing converts
between strings containing a series of <code>0</code> and <code>1</code> characters and
a sequence of bytes each containing a group of 8 bits. This is almost
as simple as it sounds, except that there are two ways the contents of
a byte may be written as a bit string. Let's have a look at an annotated
byte:</p>
<pre>
     7 6 5 4 3 2 1 0
   +-----------------+
   | 1 0 0 0 1 1 0 0 |
   +-----------------+
    MSB           LSB</pre>
<p>It's egg-eating all over again: Some think that as a bit string this should
be written ``10001100'' i.e. beginning with the most significant bit, others
insist on ``00110001''. Well, Perl isn't biased, so that's why we have two bit
string codes:</p>
<pre>
   $byte = pack( 'B8', '10001100' ); # start with MSB
   $byte = pack( 'b8', '00110001' ); # start with LSB</pre>
<p>It is not possible to pack or unpack bit fields - just integral bytes.
<code>pack</code> always starts at the next byte boundary and ``rounds up'' to the
next multiple of 8 by adding zero bits as required. (If you do want bit
fields, there is <a href="perlfunc.html#vec">vec in the perlfunc manpage</a>. Or you could implement bit field 
handling at the character string level, using split, substr, and
concatenation on unpacked bit strings.)</p>
<p>To illustrate unpacking for bit strings, we'll decompose a simple
status register (a ``-'' stands for a ``reserved'' bit):</p>
<pre>
   +-----------------+-----------------+
   | S Z - A - P - C | - - - - O D I T |
   +-----------------+-----------------+
    MSB           LSB MSB           LSB</pre>
<p>Converting these two bytes to a string can be done with the unpack 
template <code>'b16'</code>. To obtain the individual bit values from the bit
string we use <code>split</code> with the ``empty'' separator pattern which dissects
into individual characters. Bit values from the ``reserved'' positions are
simply assigned to <code>undef</code>, a convenient notation for ``I don't care where
this goes''.</p>
<pre>
   ($carry, undef, $parity, undef, $auxcarry, undef, $zero, $sign,
    $trace, $interrupt, $direction, $overflow) =
      split( //, unpack( 'b16', $status ) );</pre>
<p>We could have used an unpack template <code>'b12'</code> just as well, since the
last 4 bits can be ignored anyway.</p>
<p>
</p>
<h2><a name="uuencoding">Uuencoding</a></h2>
<p>Another odd-man-out in the template alphabet is <code>u</code>, which packs an
``uuencoded string''. (``uu'' is short for Unix-to-Unix.) Chances are that
you won't ever need this encoding technique which was invented to overcome
the shortcomings of old-fashioned transmission mediums that do not support
other than simple ASCII data. The essential recipe is simple: Take three 
bytes, or 24 bits. Split them into 4 six-packs, adding a space (0x20) to 
each. Repeat until all of the data is blended. Fold groups of 4 bytes into 
lines no longer than 60 and garnish them in front with the original byte count 
(incremented by 0x20) and a <code>&quot;\n&quot;</code> at the end. - The <code>pack</code> chef will
prepare this for you, a la minute, when you select pack code <code>u</code> on the menu:</p>
<pre>
   my $uubuf = pack( 'u', $bindat );</pre>
<p>A repeat count after <code>u</code> sets the number of bytes to put into an
uuencoded line, which is the maximum of 45 by default, but could be
set to some (smaller) integer multiple of three. <code>unpack</code> simply ignores
the repeat count.</p>
<p>
</p>
<h2><a name="doing_sums">Doing Sums</a></h2>
<p>An even stranger template code is <code>%</code>&lt;<em>number</em>&gt;. First, because 
it's used as a prefix to some other template code. Second, because it
cannot be used in <code>pack</code> at all, and third, in <code>unpack</code>, doesn't return the
data as defined by the template code it precedes. Instead it'll give you an
integer of <em>number</em> bits that is computed from the data value by 
doing sums. For numeric unpack codes, no big feat is achieved:</p>
<pre>
    my $buf = pack( 'iii', 100, 20, 3 );
    print unpack( '%32i3', $buf ), &quot;\n&quot;;  # prints 123</pre>
<p>For string values, <code>%</code> returns the sum of the byte values saving
you the trouble of a sum loop with <code>substr</code> and <code>ord</code>:</p>
<pre>
    print unpack( '%32A*', &quot;\x01\x10&quot; ), &quot;\n&quot;;  # prints 17</pre>
<p>Although the <code>%</code> code is documented as returning a ``checksum'':
don't put your trust in such values! Even when applied to a small number
of bytes, they won't guarantee a noticeable Hamming distance.</p>
<p>In connection with <code>b</code> or <code>B</code>, <code>%</code> simply adds bits, and this can be put
to good use to count set bits efficiently:</p>
<pre>
    my $bitcount = unpack( '%32b*', $mask );</pre>
<p>And an even parity bit can be determined like this:</p>
<pre>
    my $evenparity = unpack( '%1b*', $mask );</pre>
<p>
</p>
<h2><a name="unicode">Unicode</a></h2>
<p>Unicode is a character set that can represent most characters in most of
the world's languages, providing room for over one million different
characters. Unicode 3.1 specifies 94,140 characters: The Basic Latin
characters are assigned to the numbers 0 - 127. The Latin-1 Supplement with
characters that are used in several European languages is in the next
range, up to 255. After some more Latin extensions we find the character
sets from languages using non-Roman alphabets, interspersed with a
variety of symbol sets such as currency symbols, Zapf Dingbats or Braille.
(You might want to visit <em>www.unicode.org</em> for a look at some of
them - my personal favourites are Telugu and Kannada.)</p>
<p>The Unicode character sets associates characters with integers. Encoding
these numbers in an equal number of bytes would more than double the
requirements for storing texts written in Latin alphabets.
The UTF-8 encoding avoids this by storing the most common (from a western
point of view) characters in a single byte while encoding the rarer
ones in three or more bytes.</p>
<p>So what has this got to do with <code>pack</code>? Well, if you want to convert
between a Unicode number and its UTF-8 representation you can do so by
using template code <code>U</code>. As an example, let's produce the UTF-8
representation of the Euro currency symbol (code number 0x20AC):</p>
<pre>
   $UTF8{Euro} = pack( 'U', 0x20AC );</pre>
<p>Inspecting <code>$UTF8{Euro}</code> shows that it contains 3 bytes: ``\xe2\x82\xac''. The
round trip can be completed with <code>unpack</code>:</p>
<pre>
   $Unicode{Euro} = unpack( 'U', $UTF8{Euro} );</pre>
<p>Usually you'll want to pack or unpack UTF-8 strings:</p>
<pre>
   # pack and unpack the Hebrew alphabet
   my $alefbet = pack( 'U*', 0x05d0..0x05ea );
   my @hebrew = unpack( 'U*', $utf );</pre>
<p>
</p>
<h2><a name="another_portable_binary_encoding">Another Portable Binary Encoding</a></h2>
<p>The pack code <code>w</code> has been added to support a portable binary data
encoding scheme that goes way beyond simple integers. (Details can
be found at <em>Casbah.org</em>, the Scarab project.)  A BER (Binary Encoded
Representation) compressed unsigned integer stores base 128
digits, most significant digit first, with as few digits as possible.
Bit eight (the high bit) is set on each byte except the last. There
is no size limit to BER encoding, but Perl won't go to extremes.</p>
<pre>
   my $berbuf = pack( 'w*', 1, 128, 128+1, 128*128+127 );</pre>
<p>A hex dump of <code>$berbuf</code>, with spaces inserted at the right places,
shows 01 8100 8101 81807F. Since the last byte is always less than
128, <code>unpack</code> knows where to stop.</p>
<p>
</p>
<hr />
<h1><a name="template_grouping">Template Grouping</a></h1>
<p>Prior to Perl 5.8, repetitions of templates had to be made by
<code>x</code>-multiplication of template strings. Now there is a better way as
we may use the pack codes <code>(</code> and <code>)</code> combined with a repeat count.
The <code>unpack</code> template from the Stack Frame example can simply
be written like this:</p>
<pre>
   unpack( 'v2 (vXXCC)5 v5', $frame )</pre>
<p>Let's explore this feature a little more. We'll begin with the equivalent of</p>
<pre>
   join( '', map( substr( $_, 0, 1 ), @str ) )</pre>
<p>which returns a string consisting of the first character from each string.
Using pack, we can write</p>
<pre>
   pack( '(A)'.@str, @str )</pre>
<p>or, because a repeat count <code>*</code> means ``repeat as often as required'',
simply</p>
<pre>
   pack( '(A)*', @str )</pre>
<p>(Note that the template <code>A*</code> would only have packed <code>$str[0]</code> in full
length.)</p>
<p>To pack dates stored as triplets ( day, month, year ) in an array <code>@dates</code>
into a sequence of byte, byte, short integer we can write</p>
<pre>
   $pd = pack( '(CCS)*', map( @$_, @dates ) );</pre>
<p>To swap pairs of characters in a string (with even length) one could use
several techniques. First, let's use <code>x</code> and <code>X</code> to skip forward and back:</p>
<pre>
   $s = pack( '(A)*', unpack( '(xAXXAx)*', $s ) );</pre>
<p>We can also use <code>@</code> to jump to an offset, with 0 being the position where
we were when the last <code>(</code> was encountered:</p>
<pre>
   $s = pack( '(A)*', unpack( '(@1A @0A @2)*', $s ) );</pre>
<p>Finally, there is also an entirely different approach by unpacking big
endian shorts and packing them in the reverse byte order:</p>
<pre>
   $s = pack( '(v)*', unpack( '(n)*', $s );</pre>
<p>
</p>
<hr />
<h1><a name="lengths_and_widths">Lengths and Widths</a></h1>
<p>
</p>
<h2><a name="string_lengths">String Lengths</a></h2>
<p>In the previous section we've seen a network message that was constructed
by prefixing the binary message length to the actual message. You'll find
that packing a length followed by so many bytes of data is a 
frequently used recipe since appending a null byte won't work
if a null byte may be part of the data. Here is an example where both
techniques are used: after two null terminated strings with source and
destination address, a Short Message (to a mobile phone) is sent after
a length byte:</p>
<pre>
   my $msg = pack( 'Z*Z*CA*', $src, $dst, length( $sm ), $sm );</pre>
<p>Unpacking this message can be done with the same template:</p>
<pre>
   ( $src, $dst, $len, $sm ) = unpack( 'Z*Z*CA*', $msg );</pre>
<p>There's a subtle trap lurking in the offing: Adding another field after
the Short Message (in variable <code>$sm</code>) is all right when packing, but this
cannot be unpacked naively:</p>
<pre>
   # pack a message
   my $msg = pack( 'Z*Z*CA*C', $src, $dst, length( $sm ), $sm, $prio );</pre>
<pre>
   # unpack fails - $prio remains undefined!
   ( $src, $dst, $len, $sm, $prio ) = unpack( 'Z*Z*CA*C', $msg );</pre>
<p>The pack code <code>A*</code> gobbles up all remaining bytes, and <code>$prio</code> remains
undefined! Before we let disappointment dampen the morale: Perl's got
the trump card to make this trick too, just a little further up the sleeve.
Watch this:</p>
<pre>
   # pack a message: ASCIIZ, ASCIIZ, length/string, byte
   my $msg = pack( 'Z* Z* C/A* C', $src, $dst, $sm, $prio );</pre>
<pre>
   # unpack
   ( $src, $dst, $sm, $prio ) = unpack( 'Z* Z* C/A* C', $msg );</pre>
<p>Combining two pack codes with a slash (<code>/</code>) associates them with a single
value from the argument list. In <code>pack</code>, the length of the argument is
taken and packed according to the first code while the argument itself
is added after being converted with the template code after the slash.
This saves us the trouble of inserting the <code>length</code> call, but it is 
in <code>unpack</code> where we really score: The value of the length byte marks the
end of the string to be taken from the buffer. Since this combination
doesn't make sense except when the second pack code isn't <code>a*</code>, <code>A*</code>
or <code>Z*</code>, Perl won't let you.</p>
<p>The pack code preceding <code>/</code> may be anything that's fit to represent a
number: All the numeric binary pack codes, and even text codes such as
<code>A4</code> or <code>Z*</code>:</p>
<pre>
   # pack/unpack a string preceded by its length in ASCII
   my $buf = pack( 'A4/A*', &quot;Humpty-Dumpty&quot; );
   # unpack $buf: '13  Humpty-Dumpty'
   my $txt = unpack( 'A4/A*', $buf );</pre>
<p><code>/</code> is not implemented in Perls before 5.6, so if your code is required to
work on older Perls you'll need to <code>unpack( 'Z* Z* C')</code> to get the length,
then use it to make a new unpack string. For example</p>
<pre>
   # pack a message: ASCIIZ, ASCIIZ, length, string, byte (5.005 compatible)
   my $msg = pack( 'Z* Z* C A* C', $src, $dst, length $sm, $sm, $prio );</pre>
<pre>
   # unpack
   ( undef, undef, $len) = unpack( 'Z* Z* C', $msg );
   ($src, $dst, $sm, $prio) = unpack ( &quot;Z* Z* x A$len C&quot;, $msg );</pre>
<p>But that second <code>unpack</code> is rushing ahead. It isn't using a simple literal
string for the template. So maybe we should introduce...</p>
<p>
</p>
<h2><a name="dynamic_templates">Dynamic Templates</a></h2>
<p>So far, we've seen literals used as templates. If the list of pack
items doesn't have fixed length, an expression constructing the
template is required (whenever, for some reason, <code>()*</code> cannot be used).
Here's an example: To store named string values in a way that can be
conveniently parsed by a C program, we create a sequence of names and
null terminated ASCII strings, with <code>=</code> between the name and the value,
followed by an additional delimiting null byte. Here's how:</p>
<pre>
   my $env = pack( '(A*A*Z*)' . keys( %Env ) . 'C',
                   map( { ( $_, '=', $Env{$_} ) } keys( %Env ) ), 0 );</pre>
<p>Let's examine the cogs of this byte mill, one by one. There's the <code>map</code>
call, creating the items we intend to stuff into the <code>$env</code> buffer:
to each key (in <code>$_</code>) it adds the <code>=</code> separator and the hash entry value.
Each triplet is packed with the template code sequence <code>A*A*Z*</code> that
is repeated according to the number of keys. (Yes, that's what the <code>keys</code>
function returns in scalar context.) To get the very last null byte,
we add a <code>0</code> at the end of the <code>pack</code> list, to be packed with <code>C</code>.
(Attentive readers may have noticed that we could have omitted the 0.)</p>
<p>For the reverse operation, we'll have to determine the number of items
in the buffer before we can let <code>unpack</code> rip it apart:</p>
<pre>
   my $n = $env =~ tr/\0// - 1;
   my %env = map( split( /=/, $_ ), unpack( &quot;(Z*)$n&quot;, $env ) );</pre>
<p>The <code>tr</code> counts the null bytes. The <code>unpack</code> call returns a list of
name-value pairs each of which is taken apart in the <code>map</code> block.</p>
<p>
</p>
<h2><a name="counting_repetitions">Counting Repetitions</a></h2>
<p>Rather than storing a sentinel at the end of a data item (or a list of items),
we could precede the data with a count. Again, we pack keys and values of
a hash, preceding each with an unsigned short length count, and up front
we store the number of pairs:</p>
<pre>
   my $env = pack( 'S(S/A* S/A*)*', scalar keys( %Env ), %Env );</pre>
<p>This simplifies the reverse operation as the number of repetitions can be
unpacked with the <code>/</code> code:</p>
<pre>
   my %env = unpack( 'S/(S/A* S/A*)', $env );</pre>
<p>Note that this is one of the rare cases where you cannot use the same
template for <code>pack</code> and <code>unpack</code> because <code>pack</code> can't determine
a repeat count for a <code>()</code>-group.</p>
<p>
</p>
<hr />
<h1><a name="packing_and_unpacking_c_structures">Packing and Unpacking C Structures</a></h1>
<p>In previous sections we have seen how to pack numbers and character
strings. If it were not for a couple of snags we could conclude this
section right away with the terse remark that C structures don't
contain anything else, and therefore you already know all there is to it.
Sorry, no: read on, please.</p>
<p>
</p>
<h2><a name="the_alignment_pit">The Alignment Pit</a></h2>
<p>In the consideration of speed against memory requirements the balance
has been tilted in favor of faster execution. This has influenced the
way C compilers allocate memory for structures: On architectures
where a 16-bit or 32-bit operand can be moved faster between places in
memory, or to or from a CPU register, if it is aligned at an even or 
multiple-of-four or even at a multiple-of eight address, a C compiler
will give you this speed benefit by stuffing extra bytes into structures.
If you don't cross the C shoreline this is not likely to cause you any
grief (although you should care when you design large data structures,
or you want your code to be portable between architectures (you do want
that, don't you?)).</p>
<p>To see how this affects <code>pack</code> and <code>unpack</code>, we'll compare these two
C structures:</p>
<pre>
   typedef struct {
     char     c1;
     short    s;
     char     c2;
     long     l;
   } gappy_t;</pre>
<pre>
   typedef struct {
     long     l;
     short    s;
     char     c1;
     char     c2;
   } dense_t;</pre>
<p>Typically, a C compiler allocates 12 bytes to a <code>gappy_t</code> variable, but
requires only 8 bytes for a <code>dense_t</code>. After investigating this further,
we can draw memory maps, showing where the extra 4 bytes are hidden:</p>
<pre>
   0           +4          +8          +12
   +--+--+--+--+--+--+--+--+--+--+--+--+
   |c1|xx|  s  |c2|xx|xx|xx|     l     |    xx = fill byte
   +--+--+--+--+--+--+--+--+--+--+--+--+
   gappy_t</pre>
<pre>
   0           +4          +8
   +--+--+--+--+--+--+--+--+
   |     l     |  h  |c1|c2|
   +--+--+--+--+--+--+--+--+
   dense_t</pre>
<p>And that's where the first quirk strikes: <code>pack</code> and <code>unpack</code>
templates have to be stuffed with <code>x</code> codes to get those extra fill bytes.</p>
<p>The natural question: ``Why can't Perl compensate for the gaps?'' warrants
an answer. One good reason is that C compilers might provide (non-ANSI)
extensions permitting all sorts of fancy control over the way structures
are aligned, even at the level of an individual structure field. And, if
this were not enough, there is an insidious thing called <code>union</code> where
the amount of fill bytes cannot be derived from the alignment of the next
item alone.</p>
<p>OK, so let's bite the bullet. Here's one way to get the alignment right
by inserting template codes <code>x</code>, which don't take a corresponding item 
from the list:</p>
<pre>
  my $gappy = pack( 'cxs cxxx l!', $c1, $s, $c2, $l );</pre>
<p>Note the <code>!</code> after <code>l</code>: We want to make sure that we pack a long
integer as it is compiled by our C compiler. And even now, it will only
work for the platforms where the compiler aligns things as above.
And somebody somewhere has a platform where it doesn't.
[Probably a Cray, where <code>short</code>s, <code>int</code>s and <code>long</code>s are all 8 bytes. :-)]</p>
<p>Counting bytes and watching alignments in lengthy structures is bound to 
be a drag. Isn't there a way we can create the template with a simple
program? Here's a C program that does the trick:</p>
<pre>
   #include &lt;stdio.h&gt;
   #include &lt;stddef.h&gt;</pre>
<pre>
   typedef struct {
     char     fc1;
     short    fs;
     char     fc2;
     long     fl;
   } gappy_t;</pre>
<pre>
   #define Pt(struct,field,tchar) \
     printf( &quot;@%d%s &quot;, offsetof(struct,field), # tchar );</pre>
<pre>
   int main() {
     Pt( gappy_t, fc1, c  );
     Pt( gappy_t, fs,  s! );
     Pt( gappy_t, fc2, c  );
     Pt( gappy_t, fl,  l! );
     printf( &quot;\n&quot; );
   }</pre>
<p>The output line can be used as a template in a <code>pack</code> or <code>unpack</code> call:</p>
<pre>
  my $gappy = pack( '@0c @2s! @4c @8l!', $c1, $s, $c2, $l );</pre>
<p>Gee, yet another template code - as if we hadn't plenty. But 
<code>@</code> saves our day by enabling us to specify the offset from the beginning
of the pack buffer to the next item: This is just the value
the <code>offsetof</code> macro (defined in <code>&lt;stddef.h&gt;</code>) returns when
given a <code>struct</code> type and one of its field names (``member-designator'' in 
C standardese).</p>
<p>Neither using offsets nor adding <code>x</code>'s to bridge the gaps is satisfactory.
(Just imagine what happens if the structure changes.) What we really need
is a way of saying ``skip as many bytes as required to the next multiple of N''.
In fluent Templatese, you say this with <code>x!N</code> where N is replaced by the
appropriate value. Here's the next version of our struct packaging:</p>
<pre>
  my $gappy = pack( 'c x!2 s c x!4 l!', $c1, $s, $c2, $l );</pre>
<p>That's certainly better, but we still have to know how long all the
integers are, and portability is far away. Rather than <code>2</code>,
for instance, we want to say ``however long a short is''. But this can be
done by enclosing the appropriate pack code in brackets: <code>[s]</code>. So, here's
the very best we can do:</p>
<pre>
  my $gappy = pack( 'c x![s] s c x![l!] l!', $c1, $s, $c2, $l );</pre>
<p>
</p>
<h2><a name="alignment__take_2">Alignment, Take 2</a></h2>
<p>I'm afraid that we're not quite through with the alignment catch yet. The
hydra raises another ugly head when you pack arrays of structures:</p>
<pre>
   typedef struct {
     short    count;
     char     glyph;
   } cell_t;</pre>
<pre>
   typedef cell_t buffer_t[BUFLEN];</pre>
<p>Where's the catch? Padding is neither required before the first field <code>count</code>,
nor between this and the next field <code>glyph</code>, so why can't we simply pack
like this:</p>
<pre>
   # something goes wrong here:
   pack( 's!a' x @buffer,
         map{ ( $_-&gt;{count}, $_-&gt;{glyph} ) } @buffer );</pre>
<p>This packs <code>3*@buffer</code> bytes, but it turns out that the size of 
<code>buffer_t</code> is four times <code>BUFLEN</code>! The moral of the story is that
the required alignment of a structure or array is propagated to the
next higher level where we have to consider padding <em>at the end</em>
of each component as well. Thus the correct template is:</p>
<pre>
   pack( 's!ax' x @buffer,
         map{ ( $_-&gt;{count}, $_-&gt;{glyph} ) } @buffer );</pre>
<p>
</p>
<h2><a name="alignment__take_3">Alignment, Take 3</a></h2>
<p>And even if you take all the above into account, ANSI still lets this:</p>
<pre>
   typedef struct {
     char     foo[2];
   } foo_t;</pre>
<p>vary in size. The alignment constraint of the structure can be greater than
any of its elements. [And if you think that this doesn't affect anything
common, dismember the next cellphone that you see. Many have ARM cores, and
the ARM structure rules make <code>sizeof (foo_t)</code> == 4]</p>
<p>
</p>
<h2><a name="pointers_for_how_to_use_them">Pointers for How to Use Them</a></h2>
<p>The title of this section indicates the second problem you may run into
sooner or later when you pack C structures. If the function you intend
to call expects a, say, <code>void *</code> value, you <em>cannot</em> simply take
a reference to a Perl variable. (Although that value certainly is a
memory address, it's not the address where the variable's contents are
stored.)</p>
<p>Template code <code>P</code> promises to pack a ``pointer to a fixed length string''.
Isn't this what we want? Let's try:</p>
<pre>
    # allocate some storage and pack a pointer to it
    my $memory = &quot;\x00&quot; x $size;
    my $memptr = pack( 'P', $memory );</pre>
<p>But wait: doesn't <code>pack</code> just return a sequence of bytes? How can we pass this
string of bytes to some C code expecting a pointer which is, after all,
nothing but a number? The answer is simple: We have to obtain the numeric
address from the bytes returned by <code>pack</code>.</p>
<pre>
    my $ptr = unpack( 'L!', $memptr );</pre>
<p>Obviously this assumes that it is possible to typecast a pointer
to an unsigned long and vice versa, which frequently works but should not
be taken as a universal law. - Now that we have this pointer the next question
is: How can we put it to good use? We need a call to some C function
where a pointer is expected. The <code>read(2)</code> system call comes to mind:</p>
<pre>
    ssize_t read(int fd, void *buf, size_t count);</pre>
<p>After reading <a href="perlfunc.html">the perlfunc manpage</a> explaining how to use <code>syscall</code> we can write
this Perl function copying a file to standard output:</p>
<pre>
    require 'syscall.ph';
    sub cat($){
        my $path = shift();
        my $size = -s $path;
        my $memory = &quot;\x00&quot; x $size;  # allocate some memory
        my $ptr = unpack( 'L', pack( 'P', $memory ) );
        open( F, $path ) || die( &quot;$path: cannot open ($!)\n&quot; );
        my $fd = fileno(F);
        my $res = syscall( &amp;SYS_read, fileno(F), $ptr, $size );
        print $memory;
        close( F );
    }</pre>
<p>This is neither a specimen of simplicity nor a paragon of portability but
it illustrates the point: We are able to sneak behind the scenes and
access Perl's otherwise well-guarded memory! (Important note: Perl's
<code>syscall</code> does <em>not</em> require you to construct pointers in this roundabout
way. You simply pass a string variable, and Perl forwards the address.)</p>
<p>How does <code>unpack</code> with <code>P</code> work? Imagine some pointer in the buffer
about to be unpacked: If it isn't the null pointer (which will smartly
produce the <code>undef</code> value) we have a start address - but then what?
Perl has no way of knowing how long this ``fixed length string'' is, so
it's up to you to specify the actual size as an explicit length after <code>P</code>.</p>
<pre>
   my $mem = &quot;abcdefghijklmn&quot;;
   print unpack( 'P5', pack( 'P', $mem ) ); # prints &quot;abcde&quot;</pre>
<p>As a consequence, <code>pack</code> ignores any number or <code>*</code> after <code>P</code>.</p>
<p>Now that we have seen <code>P</code> at work, we might as well give <code>p</code> a whirl.
Why do we need a second template code for packing pointers at all? The 
answer lies behind the simple fact that an <code>unpack</code> with <code>p</code> promises
a null-terminated string starting at the address taken from the buffer,
and that implies a length for the data item to be returned:</p>
<pre>
   my $buf = pack( 'p', &quot;abc\x00efhijklmn&quot; );
   print unpack( 'p', $buf );    # prints &quot;abc&quot;</pre>
<p>Albeit this is apt to be confusing: As a consequence of the length being
implied by the string's length, a number after pack code <code>p</code> is a repeat
count, not a length as after <code>P</code>.</p>
<p>Using <code>pack(..., $x)</code> with <code>P</code> or <code>p</code> to get the address where <code>$x</code> is
actually stored must be used with circumspection. Perl's internal machinery
considers the relation between a variable and that address as its very own 
private matter and doesn't really care that we have obtained a copy. Therefore:</p>
<ul>
<li>
<p>Do not use <code>pack</code> with <code>p</code> or <code>P</code> to obtain the address of variable
that's bound to go out of scope (and thereby freeing its memory) before you
are done with using the memory at that address.</p>
</li>
<li>
<p>Be very careful with Perl operations that change the value of the
variable. Appending something to the variable, for instance, might require
reallocation of its storage, leaving you with a pointer into no-man's land.</p>
</li>
<li>
<p>Don't think that you can get the address of a Perl variable
when it is stored as an integer or double number! <code>pack('P', $x)</code> will
force the variable's internal representation to string, just as if you
had written something like <code>$x .= ''</code>.</p>
</li>
</ul>
<p>It's safe, however, to P- or p-pack a string literal, because Perl simply
allocates an anonymous variable.</p>
<p>
</p>
<hr />
<h1><a name="pack_recipes">Pack Recipes</a></h1>
<p>Here are a collection of (possibly) useful canned recipes for <code>pack</code>
and <code>unpack</code>:</p>
<pre>
    # Convert IP address for socket functions
    pack( &quot;C4&quot;, split /\./, &quot;123.4.5.6&quot; );</pre>
<pre>
    # Count the bits in a chunk of memory (e.g. a select vector)
    unpack( '%32b*', $mask );</pre>
<pre>
    # Determine the endianness of your system
    $is_little_endian = unpack( 'c', pack( 's', 1 ) );
    $is_big_endian = unpack( 'xc', pack( 's', 1 ) );</pre>
<pre>
    # Determine the number of bits in a native integer
    $bits = unpack( '%32I!', ~0 );</pre>
<pre>
    # Prepare argument for the nanosleep system call
    my $timespec = pack( 'L!L!', $secs, $nanosecs );</pre>
<p>For a simple memory dump we unpack some bytes into just as 
many pairs of hex digits, and use <code>map</code> to handle the traditional
spacing - 16 bytes to a line:</p>
<pre>
    my $i;
    print map( ++$i % 16 ? &quot;$_ &quot; : &quot;$_\n&quot;,
               unpack( 'H2' x length( $mem ), $mem ) ),
          length( $mem ) % 16 ? &quot;\n&quot; : '';</pre>
<p>
</p>
<hr />
<h1><a name="funnies_section">Funnies Section</a></h1>
<pre>
    # Pulling digits out of nowhere...
    print unpack( 'C', pack( 'x' ) ),
          unpack( '%B*', pack( 'A' ) ),
          unpack( 'H', pack( 'A' ) ),
          unpack( 'A', unpack( 'C', pack( 'A' ) ) ), &quot;\n&quot;;</pre>
<pre>
    # One for the road ;-)
    my $advice = pack( 'all u can in a van' );</pre>
<p>
</p>
<hr />
<h1><a name="authors">Authors</a></h1>
<p>Simon Cozens and Wolfgang Laun.</p>
<table border="0" width="100%" cellspacing="0" cellpadding="3">
<tr><td class="block" style="background-color: #cccccc" valign="middle">
<big><strong><span class="block">&nbsp;perlpacktut - tutorial on C&lt;pack&gt; and C&lt;unpack&gt;</span></strong></big>
</td></tr>
</table>

</body>

</html>
