<?xml version="1.0" ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>perlpodspec - Plain Old Documentation: format specification and notes</title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rev="made" href="mailto:root@localhost" />
</head>

<body style="background-color: white">
<table border="0" width="100%" cellspacing="0" cellpadding="3">
<tr><td class="block" style="background-color: #cccccc" valign="middle">
<big><strong><span class="block">&nbsp;perlpodspec - Plain Old Documentation: format specification and notes</span></strong></big>
</td></tr>
</table>

<p><a name="__index__"></a></p>
<!-- INDEX BEGIN -->

<ul>

	<li><a href="#name">NAME</a></li>
	<li><a href="#description">DESCRIPTION</a></li>
	<li><a href="#pod_definitions">Pod Definitions</a></li>
	<li><a href="#pod_commands">Pod Commands</a></li>
	<li><a href="#pod_formatting_codes">Pod Formatting Codes</a></li>
	<li><a href="#notes_on_implementing_pod_processors">Notes on Implementing Pod Processors</a></li>
	<li><a href="#about_l______codes">About L&lt;...&gt; Codes</a></li>
	<li><a href="#about__over____back_regions">About =over...=back Regions</a></li>
	<li><a href="#about_data_paragraphs_and__begin__end_regions">About Data Paragraphs and ``=begin/=end'' Regions</a></li>
	<li><a href="#see_also">SEE ALSO</a></li>
	<li><a href="#author">AUTHOR</a></li>
</ul>
<!-- INDEX END -->

<hr />
<p>
</p>
<h1><a name="name">NAME</a></h1>
<p>perlpodspec - Plain Old Documentation: format specification and notes</p>
<p>
</p>
<hr />
<h1><a name="description">DESCRIPTION</a></h1>
<p>This document is detailed notes on the Pod markup language.  Most
people will only have to read <a href="perlpod.html">perlpod</a> to know how to write
in Pod, but this document may answer some incidental questions to do
with parsing and rendering Pod.</p>
<p>In this document, ``must'' / ``must not'', ``should'' /
``should not'', and ``may'' have their conventional (cf. RFC 2119)
meanings: ``X must do Y'' means that if X doesn't do Y, it's against
this specification, and should really be fixed.  ``X should do Y''
means that it's recommended, but X may fail to do Y, if there's a
good reason.  ``X may do Y'' is merely a note that X can do Y at
will (although it is up to the reader to detect any connotation of
``and I think it would be <em>nice</em> if X did Y'' versus ``it wouldn't
really <em>bother</em> me if X did Y'').</p>
<p>Notably, when I say ``the parser should do Y'', the
parser may fail to do Y, if the calling application explicitly
requests that the parser <em>not</em> do Y.  I often phrase this as
``the parser should, by default, do Y.''  This doesn't <em>require</em>
the parser to provide an option for turning off whatever
feature Y is (like expanding tabs in verbatim paragraphs), although
it implicates that such an option <em>may</em> be provided.</p>
<p>
</p>
<hr />
<h1><a name="pod_definitions">Pod Definitions</a></h1>
<p>Pod is embedded in files, typically Perl source files -- although you
can write a file that's nothing but Pod.</p>
<p>A <strong>line</strong> in a file consists of zero or more non-newline characters,
terminated by either a newline or the end of the file.</p>
<p>A <strong>newline sequence</strong> is usually a platform-dependent concept, but
Pod parsers should understand it to mean any of CR (ASCII 13), LF
(ASCII 10), or a CRLF (ASCII 13 followed immediately by ASCII 10), in
addition to any other system-specific meaning.  The first CR/CRLF/LF
sequence in the file may be used as the basis for identifying the
newline sequence for parsing the rest of the file.</p>
<p>A <strong>blank line</strong> is a line consisting entirely of zero or more spaces
(ASCII 32) or tabs (ASCII 9), and terminated by a newline or end-of-file.
A <strong>non-blank line</strong> is a line containing one or more characters other
than space or tab (and terminated by a newline or end-of-file).</p>
<p>(<em>Note:</em> Many older Pod parsers did not accept a line consisting of
spaces/tabs and then a newline as a blank line -- the only lines they
considered blank were lines consisting of <em>no characters at all</em>,
terminated by a newline.)</p>
<p><strong>Whitespace</strong> is used in this document as a blanket term for spaces,
tabs, and newline sequences.  (By itself, this term usually refers
to literal whitespace.  That is, sequences of whitespace characters
in Pod source, as opposed to ``E&lt;32&gt;'', which is a formatting
code that <em>denotes</em> a whitespace character.)</p>
<p>A <strong>Pod parser</strong> is a module meant for parsing Pod (regardless of
whether this involves calling callbacks or building a parse tree or
directly formatting it).  A <strong>Pod formatter</strong> (or <strong>Pod translator</strong>)
is a module or program that converts Pod to some other format (HTML,
plaintext, TeX, PostScript, RTF).  A <strong>Pod processor</strong> might be a
formatter or translator, or might be a program that does something
else with the Pod (like wordcounting it, scanning for index points,
etc.).</p>
<p>Pod content is contained in <strong>Pod blocks</strong>.  A Pod block starts with a
line that matches &lt;m/\A=[a-zA-Z]/&gt;, and continues up to the next line
that matches <code>m/\A=cut/</code> -- or up to the end of the file, if there is
no <code>m/\A=cut/</code> line.</p>
<p>Within a Pod block, there are <strong>Pod paragraphs</strong>.  A Pod paragraph
consists of non-blank lines of text, separated by one or more blank
lines.</p>
<p>For purposes of Pod processing, there are four types of paragraphs in
a Pod block:</p>
<ul>
<li>
<p>A command paragraph (also called a ``directive'').  The first line of
this paragraph must match <code>m/\A=[a-zA-Z]/</code>.  Command paragraphs are
typically one line, as in:</p>
<pre>
  =head1 NOTES</pre>
<pre>
  =item *</pre>
<p>But they may span several (non-blank) lines:</p>
<pre>
  =for comment
  Hm, I wonder what it would look like if
  you tried to write a BNF for Pod from this.</pre>
<pre>
  =head3 Dr. Strangelove, or: How I Learned to
  Stop Worrying and Love the Bomb</pre>
<p><em>Some</em> command paragraphs allow formatting codes in their content
(i.e., after the part that matches <code>m/\A=[a-zA-Z]\S*\s*/</code>), as in:</p>
<pre>
  =head1 Did You Remember to C&lt;use strict;&gt;?</pre>
<p>In other words, the Pod processing handler for ``head1'' will apply the
same processing to ``Did You Remember to C&lt;use strict;&gt;?'' that it
would to an ordinary paragraph -- i.e., formatting codes (like
``C&lt;...&gt;'') are parsed and presumably formatted appropriately, and
whitespace in the form of literal spaces and/or tabs is not
significant.</p>
</li>
<li>
<p>A <strong>verbatim paragraph</strong>.  The first line of this paragraph must be a
literal space or tab, and this paragraph must not be inside a ``=begin
<em>identifier</em>'', ... ``=end <em>identifier</em>'' sequence unless
``<em>identifier</em>'' begins with a colon (``:'').  That is, if a paragraph
starts with a literal space or tab, but <em>is</em> inside a
``=begin <em>identifier</em>'', ... ``=end <em>identifier</em>'' region, then it's
a data paragraph, unless ``<em>identifier</em>'' begins with a colon.</p>
<p>Whitespace <em>is</em> significant in verbatim paragraphs (although, in
processing, tabs are probably expanded).</p>
</li>
<li>
<p>An <strong>ordinary paragraph</strong>.  A paragraph is an ordinary paragraph
if its first line matches neither <code>m/\A=[a-zA-Z]/</code> nor
<code>m/\A[ \t]/</code>, <em>and</em> if it's not inside a ``=begin <em>identifier</em>'',
... ``=end <em>identifier</em>'' sequence unless ``<em>identifier</em>'' begins with
a colon (``:'').</p>
</li>
<li>
<p>A <strong>data paragraph</strong>.  This is a paragraph that <em>is</em> inside a ``=begin
<em>identifier</em>'' ... ``=end <em>identifier</em>'' sequence where
``<em>identifier</em>'' does <em>not</em> begin with a literal colon (``:'').  In
some sense, a data paragraph is not part of Pod at all (i.e.,
effectively it's ``out-of-band''), since it's not subject to most kinds
of Pod parsing; but it is specified here, since Pod
parsers need to be able to call an event for it, or store it in some
form in a parse tree, or at least just parse <em>around</em> it.</p>
</li>
</ul>
<p>For example: consider the following paragraphs:</p>
<pre>
  # &lt;- that's the 0th column</pre>
<pre>
  =head1 Foo</pre>
<pre>
  Stuff</pre>
<pre>
    $foo-&gt;bar</pre>
<pre>
  =cut</pre>
<p>Here, ``=head1 Foo'' and ``=cut'' are command paragraphs because the first
line of each matches <code>m/\A=[a-zA-Z]/</code>.  ``<em>[space][space]</em>$foo-&gt;bar''
is a verbatim paragraph, because its first line starts with a literal
whitespace character (and there's no ``=begin''...``=end'' region around).</p>
<p>The ``=begin <em>identifier</em>'' ... ``=end <em>identifier</em>'' commands stop
paragraphs that they surround from being parsed as data or verbatim
paragraphs, if <em>identifier</em> doesn't begin with a colon.  This
is discussed in detail in the section
<a href="#about_data_paragraphs_and__begine_sol__end_regions">About Data Paragraphs and ``=begin&sol;=end'' Regions</a>.</p>
<p>
</p>
<hr />
<h1><a name="pod_commands">Pod Commands</a></h1>
<p>This section is intended to supplement and clarify the discussion in
<a href="perlpod.html#command_paragraph">Command Paragraph in the perlpod manpage</a>.  These are the currently recognized
Pod commands:</p>
<dl>
<dt><strong><a name="item__22_3dhead1_22_2c__22_3dhead2_22_2c__22_3dhead3_22">``=head1'', ``=head2'', ``=head3'', ``=head4''</a></strong>

<dd>
<p>This command indicates that the text in the remainder of the paragraph
is a heading.  That text may contain formatting codes.  Examples:</p>
</dd>
<dd>
<pre>
  =head1 Object Attributes</pre>
</dd>
<dd>
<pre>
  =head3 What B&lt;Not&gt; to Do!</pre>
</dd>
</li>
<dt><strong><a name="item__22_3dpod_22">``=pod''</a></strong>

<dd>
<p>This command indicates that this paragraph begins a Pod block.  (If we
are already in the middle of a Pod block, this command has no effect at
all.)  If there is any text in this command paragraph after ``=pod'',
it must be ignored.  Examples:</p>
</dd>
<dd>
<pre>
  =pod</pre>
</dd>
<dd>
<pre>
  This is a plain Pod paragraph.</pre>
</dd>
<dd>
<pre>
  =pod This text is ignored.</pre>
</dd>
</li>
<dt><strong><a name="item__22_3dcut_22">``=cut''</a></strong>

<dd>
<p>This command indicates that this line is the end of this previously
started Pod block.  If there is any text after ``=cut'' on the line, it must be
ignored.  Examples:</p>
</dd>
<dd>
<pre>
  =cut</pre>
</dd>
<dd>
<pre>
  =cut The documentation ends here.</pre>
</dd>
<dd>
<pre>
  =cut
  # This is the first line of program text.
  sub foo { # This is the second.</pre>
</dd>
<dd>
<p>It is an error to try to <em>start</em> a Pod block with a ``=cut'' command.  In
that case, the Pod processor must halt parsing of the input file, and
must by default emit a warning.</p>
</dd>
</li>
<dt><strong><a name="item__22_3dover_22">``=over''</a></strong>

<dd>
<p>This command indicates that this is the start of a list/indent
region.  If there is any text following the ``=over'', it must consist
of only a nonzero positive numeral.  The semantics of this numeral is
explained in the <a href="#about__over____back_regions">About =over...=back Regions</a> section, further
below.  Formatting codes are not expanded.  Examples:</p>
</dd>
<dd>
<pre>
  =over 3</pre>
</dd>
<dd>
<pre>
  =over 3.5</pre>
</dd>
<dd>
<pre>
  =over</pre>
</dd>
</li>
<dt><strong><a name="item__22_3ditem_22">``=item''</a></strong>

<dd>
<p>This command indicates that an item in a list begins here.  Formatting
codes are processed.  The semantics of the (optional) text in the
remainder of this paragraph are
explained in the <a href="#about__over____back_regions">About =over...=back Regions</a> section, further
below.  Examples:</p>
</dd>
<dd>
<pre>
  =item</pre>
</dd>
<dd>
<pre>
  =item *</pre>
</dd>
<dd>
<pre>
  =item      *</pre>
</dd>
<dd>
<pre>
  =item 14</pre>
</dd>
<dd>
<pre>
  =item   3.</pre>
</dd>
<dd>
<pre>
  =item C&lt;&lt; $thing-&gt;stuff(I&lt;dodad&gt;) &gt;&gt;</pre>
</dd>
<dd>
<pre>
  =item For transporting us beyond seas to be tried for pretended
  offenses</pre>
</dd>
<dd>
<pre>
  =item He is at this time transporting large armies of foreign
  mercenaries to complete the works of death, desolation and
  tyranny, already begun with circumstances of cruelty and perfidy
  scarcely paralleled in the most barbarous ages, and totally
  unworthy the head of a civilized nation.</pre>
</dd>
</li>
<dt><strong><a name="item__22_3dback_22">``=back''</a></strong>

<dd>
<p>This command indicates that this is the end of the region begun
by the most recent ``=over'' command.  It permits no text after the
``=back'' command.</p>
</dd>
</li>
<dt><strong><a name="item__22_3dbegin_formatname_22">``=begin formatname''</a></strong>

<dd>
<p>This marks the following paragraphs (until the matching ``=end
formatname'') as being for some special kind of processing.  Unless
``formatname'' begins with a colon, the contained non-command
paragraphs are data paragraphs.  But if ``formatname'' <em>does</em> begin
with a colon, then non-command paragraphs are ordinary paragraphs
or data paragraphs.  This is discussed in detail in the section
<a href="#about_data_paragraphs_and__begine_sol__end_regions">About Data Paragraphs and ``=begin&sol;=end'' Regions</a>.</p>
</dd>
<dd>
<p>It is advised that formatnames match the regexp
<code>m/\A:?[-a-zA-Z0-9_]+\z/</code>.  Implementors should anticipate future
expansion in the semantics and syntax of the first parameter
to ``=begin''/``=end''/``=for''.</p>
</dd>
</li>
<dt><strong><a name="item__22_3dend_formatname_22">``=end formatname''</a></strong>

<dd>
<p>This marks the end of the region opened by the matching
``=begin formatname'' region.  If ``formatname'' is not the formatname
of the most recent open ``=begin formatname'' region, then this
is an error, and must generate an error message.  This
is discussed in detail in the section
<a href="#about_data_paragraphs_and__begine_sol__end_regions">About Data Paragraphs and ``=begin&sol;=end'' Regions</a>.</p>
</dd>
</li>
<dt><strong><a name="item__22_3dfor_formatname_text_2e_2e_2e_22">``=for formatname text...''</a></strong>

<dd>
<p>This is synonymous with:</p>
</dd>
<dd>
<pre>
     =begin formatname</pre>
</dd>
<dd>
<pre>
     text...</pre>
</dd>
<dd>
<pre>
     =end formatname</pre>
</dd>
<dd>
<p>That is, it creates a region consisting of a single paragraph; that
paragraph is to be treated as a normal paragraph if ``formatname''
begins with a ``:''; if ``formatname'' <em>doesn't</em> begin with a colon,
then ``text...'' will constitute a data paragraph.  There is no way
to use ``=for formatname text...'' to express ``text...'' as a verbatim
paragraph.</p>
</dd>
</li>
<dt><strong><a name="item__22_3dencoding_encodingname_22">``=encoding encodingname''</a></strong>

<dd>
<p>This command, which should occur early in the document (at least
before any non-US-ASCII data!), declares that this document is
encoded in the encoding <em>encodingname</em>, which must be
an encoding name that <a href="../../Encode/Encoding.html">the Encoding manpage</a> recognizes.  (Encoding's list
of supported encodings, in <a href="../../Encoding/Supported.html">the Encoding::Supported manpage</a>, is useful here.)
If the Pod parser cannot decode the declared encoding, it 
should emit a warning and may abort parsing the document
altogether.</p>
</dd>
<dd>
<p>A document having more than one ``=encoding'' line should be
considered an error.  Pod processors may silently tolerate this if
the not-first ``=encoding'' lines are just duplicates of the
first one (e.g., if there's a ``=use utf8'' line, and later on
another ``=use utf8'' line).  But Pod processors should complain if
there are contradictory ``=encoding'' lines in the same document
(e.g., if there is a ``=encoding utf8'' early in the document and
``=encoding big5'' later).  Pod processors that recognize BOMs
may also complain if they see an ``=encoding'' line
that contradicts the BOM (e.g., if a document with a UTF-16LE
BOM has an ``=encoding shiftjis'' line).</p>
</dd>
</li>
</dl>
<p>If a Pod processor sees any command other than the ones listed
above (like ``=head'', or ``=haed1'', or ``=stuff'', or ``=cuttlefish'',
or ``=w123''), that processor must by default treat this as an
error.  It must not process the paragraph beginning with that
command, must by default warn of this as an error, and may
abort the parse.  A Pod parser may allow a way for particular
applications to add to the above list of known commands, and to
stipulate, for each additional command, whether formatting
codes should be processed.</p>
<p>Future versions of this specification may add additional
commands.</p>
<p>
</p>
<hr />
<h1><a name="pod_formatting_codes">Pod Formatting Codes</a></h1>
<p>(Note that in previous drafts of this document and of perlpod,
formatting codes were referred to as ``interior sequences'', and
this term may still be found in the documentation for Pod parsers,
and in error messages from Pod processors.)</p>
<p>There are two syntaxes for formatting codes:</p>
<ul>
<li>
<p>A formatting code starts with a capital letter (just US-ASCII [A-Z])
followed by a ``&lt;'', any number of characters, and ending with the first
matching ``&gt;''.  Examples:</p>
<pre>
    That's what I&lt;you&gt; think!</pre>
<pre>
    What's C&lt;dump()&gt; for?</pre>
<pre>
    X&lt;C&lt;chmod&gt; and C&lt;unlink()&gt; Under Different Operating Systems&gt;</pre>
</li>
<li>
<p>A formatting code starts with a capital letter (just US-ASCII [A-Z])
followed by two or more ``&lt;'''s, one or more whitespace characters,
any number of characters, one or more whitespace characters,
and ending with the first matching sequence of two or more ``&gt;'''s, where
the number of ``&gt;'''s equals the number of ``&lt;'''s in the opening of this
formatting code.  Examples:</p>
<pre>
    That's what I&lt;&lt; you &gt;&gt; think!</pre>
<pre>
    C&lt;&lt;&lt; open(X, &quot;&gt;&gt;thing.dat&quot;) || die $! &gt;&gt;&gt;</pre>
<pre>
    B&lt;&lt; $foo-&gt;bar(); &gt;&gt;</pre>
<p>With this syntax, the whitespace <code>character(s)</code> after the ``C&lt;&lt;&lt;''
and before the ``&gt;&gt;'' (or whatever letter) are <em>not</em> renderable -- they
do not signify whitespace, are merely part of the formatting codes
themselves.  That is, these are all synonymous:</p>
<pre>
    C&lt;thing&gt;
    C&lt;&lt; thing &gt;&gt;
    C&lt;&lt;           thing     &gt;&gt;
    C&lt;&lt;&lt;   thing &gt;&gt;&gt;
    C&lt;&lt;&lt;&lt;
    thing
               &gt;&gt;&gt;&gt;</pre>
<p>and so on.</p>
</li>
</ul>
<p>In parsing Pod, a notably tricky part is the correct parsing of
(potentially nested!) formatting codes.  Implementors should
consult the code in the <code>parse_text</code> routine in Pod::Parser as an
example of a correct implementation.</p>
<dl>
<dt><strong><a name="item_i_3ctext_3e__2d_2d_italic_text"><code>I&lt;text&gt;</code> -- italic text</a></strong>

<dd>
<p>See the brief discussion in <a href="perlpod.html#formatting_codes">Formatting Codes in the perlpod manpage</a>.</p>
</dd>
</li>
<dt><strong><a name="item_b_3ctext_3e__2d_2d_bold_text"><code>B&lt;text&gt;</code> -- bold text</a></strong>

<dd>
<p>See the brief discussion in <a href="perlpod.html#formatting_codes">Formatting Codes in the perlpod manpage</a>.</p>
</dd>
</li>
<dt><strong><a name="item_c_3ccode_3e__2d_2d_code_text"><code>C&lt;code&gt;</code> -- code text</a></strong>

<dd>
<p>See the brief discussion in <a href="perlpod.html#formatting_codes">Formatting Codes in the perlpod manpage</a>.</p>
</dd>
</li>
<dt><strong><a name="item_f_3cfilename_3e__2d_2d_style_for_filenames"><code>F&lt;filename&gt;</code> -- style for filenames</a></strong>

<dd>
<p>See the brief discussion in <a href="perlpod.html#formatting_codes">Formatting Codes in the perlpod manpage</a>.</p>
</dd>
</li>
<dt><strong><a name="item_x_3ctopic_name_3e__2d_2d_an_index_entry"><code>X&lt;topic name&gt;</code> -- an index entry</a></strong>

<dd>
<p>See the brief discussion in <a href="perlpod.html#formatting_codes">Formatting Codes in the perlpod manpage</a>.</p>
</dd>
<dd>
<p>This code is unusual in that most formatters completely discard
this code and its content.  Other formatters will render it with
invisible codes that can be used in building an index of
the current document.</p>
</dd>
</li>
<dt><strong><a name="item_null"><code>Z&lt;&gt;</code> -- a null (zero-effect) formatting code</a></strong>

<dd>
<p>Discussed briefly in <a href="perlpod.html#formatting_codes">Formatting Codes in the perlpod manpage</a>.</p>
</dd>
<dd>
<p>This code is unusual is that it should have no content.  That is,
a processor may complain if it sees <code>Z&lt;potatoes&gt;</code>.  Whether
or not it complains, the <em>potatoes</em> text should ignored.</p>
</dd>
</li>
<dt><strong><a name="item_l_3cname_3e__2d_2d_a_hyperlink"><code>L&lt;name&gt;</code> -- a hyperlink</a></strong>

<dd>
<p>The complicated syntaxes of this code are discussed at length in
<a href="perlpod.html#formatting_codes">Formatting Codes in the perlpod manpage</a>, and implementation details are
discussed below, in <a href="#about_le_lt____e_gt__codes">About L&lt;...&gt; Codes</a>.  Parsing the
contents of L&lt;content&gt; is tricky.  Notably, the content has to be
checked for whether it looks like a URL, or whether it has to be split
on literal ``|'' and/or ``/'' (in the right order!), and so on,
<em>before</em> E&lt;...&gt; codes are resolved.</p>
</dd>
</li>
<dt><strong><a name="item_e_3cescape_3e__2d_2d_a_character_escape"><code>E&lt;escape&gt;</code> -- a character escape</a></strong>

<dd>
<p>See <a href="perlpod.html#formatting_codes">Formatting Codes in the perlpod manpage</a>, and several points in
<a href="#notes_on_implementing_pod_processors">Notes on Implementing Pod Processors</a>.</p>
</dd>
</li>
<dt><strong><a name="item_s_3ctext_3e__2d_2d_text_contains_non_2dbreaking_sp"><code>S&lt;text&gt;</code> -- text contains non-breaking spaces</a></strong>

<dd>
<p>This formatting code is syntactically simple, but semantically
complex.  What it means is that each space in the printable
content of this code signifies a non-breaking space.</p>
</dd>
<dd>
<p>Consider:</p>
</dd>
<dd>
<pre>
    C&lt;$x ? $y    :  $z&gt;</pre>
</dd>
<dd>
<pre>
    S&lt;C&lt;$x ? $y     :  $z&gt;&gt;</pre>
</dd>
<dd>
<p>Both signify the monospace (c[ode] style) text consisting of
``$x'', one space, ``?'', one space, ``:'', one space, ``$z''.  The
difference is that in the latter, with the S code, those spaces
are not ``normal'' spaces, but instead are non-breaking spaces.</p>
</dd>
</li>
</dl>
<p>If a Pod processor sees any formatting code other than the ones
listed above (as in ``N&lt;...&gt;'', or ``Q&lt;...&gt;'', etc.), that
processor must by default treat this as an error.
A Pod parser may allow a way for particular
applications to add to the above list of known formatting codes;
a Pod parser might even allow a way to stipulate, for each additional
command, whether it requires some form of special processing, as
L&lt;...&gt; does.</p>
<p>Future versions of this specification may add additional
formatting codes.</p>
<p>Historical note:  A few older Pod processors would not see a ``&gt;'' as
closing a ``C&lt;'' code, if the ``&gt;'' was immediately preceded by
a ``-''.  This was so that this:</p>
<pre>
    C&lt;$foo-&gt;bar&gt;</pre>
<p>would parse as equivalent to this:</p>
<pre>
    C&lt;$foo-E&lt;gt&gt;bar&gt;</pre>
<p>instead of as equivalent to a ``C'' formatting code containing 
only ``$foo-'', and then a ``bar&gt;'' outside the ``C'' formatting code.  This
problem has since been solved by the addition of syntaxes like this:</p>
<pre>
    C&lt;&lt; $foo-&gt;bar &gt;&gt;</pre>
<p>Compliant parsers must not treat ``-&gt;'' as special.</p>
<p>Formatting codes absolutely cannot span paragraphs.  If a code is
opened in one paragraph, and no closing code is found by the end of
that paragraph, the Pod parser must close that formatting code,
and should complain (as in ``Unterminated I code in the paragraph
starting at line 123: 'Time objects are not...''').  So these
two paragraphs:</p>
<pre>
  I&lt;I told you not to do this!</pre>
<pre>
  Don't make me say it again!&gt;</pre>
<p>...must <em>not</em> be parsed as two paragraphs in italics (with the I
code starting in one paragraph and starting in another.)  Instead,
the first paragraph should generate a warning, but that aside, the
above code must parse as if it were:</p>
<pre>
  I&lt;I told you not to do this!&gt;</pre>
<pre>
  Don't make me say it again!E&lt;gt&gt;</pre>
<p>(In SGMLish jargon, all Pod commands are like block-level
elements, whereas all Pod formatting codes are like inline-level
elements.)</p>
<p>
</p>
<hr />
<h1><a name="notes_on_implementing_pod_processors">Notes on Implementing Pod Processors</a></h1>
<p>The following is a long section of miscellaneous requirements
and suggestions to do with Pod processing.</p>
<ul>
<li>
<p>Pod formatters should tolerate lines in verbatim blocks that are of
any length, even if that means having to break them (possibly several
times, for very long lines) to avoid text running off the side of the
page.  Pod formatters may warn of such line-breaking.  Such warnings
are particularly appropriate for lines are over 100 characters long, which
are usually not intentional.</p>
</li>
<li>
<p>Pod parsers must recognize <em>all</em> of the three well-known newline
formats: CR, LF, and CRLF.  See <a href="perlport.html">perlport</a>.</p>
</li>
<li>
<p>Pod parsers should accept input lines that are of any length.</p>
</li>
<li>
<p>Since Perl recognizes a Unicode Byte Order Mark at the start of files
as signaling that the file is Unicode encoded as in UTF-16 (whether
big-endian or little-endian) or UTF-8, Pod parsers should do the
same.  Otherwise, the character encoding should be understood as
being UTF-8 if the first highbit byte sequence in the file seems
valid as a UTF-8 sequence, or otherwise as Latin-1.</p>
<p>Future versions of this specification may specify
how Pod can accept other encodings.  Presumably treatment of other
encodings in Pod parsing would be as in XML parsing: whatever the
encoding declared by a particular Pod file, content is to be
stored in memory as Unicode characters.</p>
</li>
<li>
<p>The well known Unicode Byte Order Marks are as follows:  if the
file begins with the two literal byte values 0xFE 0xFF, this is
the BOM for big-endian UTF-16.  If the file begins with the two
literal byte value 0xFF 0xFE, this is the BOM for little-endian
UTF-16.  If the file begins with the three literal byte values
0xEF 0xBB 0xBF, this is the BOM for UTF-8.</p>
</li>
<li>
<p>A naive but sufficient heuristic for testing the first highbit
byte-sequence in a BOM-less file (whether in code or in Pod!), to see
whether that sequence is valid as UTF-8 (RFC 2279) is to check whether
that the first byte in the sequence is in the range 0xC0 - 0xFD
<em>and</em> whether the next byte is in the range
0x80 - 0xBF.  If so, the parser may conclude that this file is in
UTF-8, and all highbit sequences in the file should be assumed to
be UTF-8.  Otherwise the parser should treat the file as being
in Latin-1.  In the unlikely circumstance that the first highbit
sequence in a truly non-UTF-8 file happens to appear to be UTF-8, one
can cater to our heuristic (as well as any more intelligent heuristic)
by prefacing that line with a comment line containing a highbit
sequence that is clearly <em>not</em> valid as UTF-8.  A line consisting
of simply ``#'', an e-acute, and any non-highbit byte,
is sufficient to establish this file's encoding.</p>
</li>
<li>
<p>This document's requirements and suggestions about encodings
do not apply to Pod processors running on non-ASCII platforms,
notably EBCDIC platforms.</p>
</li>
<li>
<p>Pod processors must treat a ``=for [label] [content...]'' paragraph as
meaning the same thing as a ``=begin [label]'' paragraph, content, and
an ``=end [label]'' paragraph.  (The parser may conflate these two
constructs, or may leave them distinct, in the expectation that the
formatter will nevertheless treat them the same.)</p>
</li>
<li>
<p>When rendering Pod to a format that allows comments (i.e., to nearly
any format other than plaintext), a Pod formatter must insert comment
text identifying its name and version number, and the name and
version numbers of any modules it might be using to process the Pod.
Minimal examples:</p>
<pre>
  %% POD::Pod2PS v3.14159, using POD::Parser v1.92</pre>
<pre>
  &lt;!-- Pod::HTML v3.14159, using POD::Parser v1.92 --&gt;</pre>
<pre>
  {\doccomm generated by Pod::Tree::RTF 3.14159 using Pod::Tree 1.08}</pre>
<pre>
  .\&quot; Pod::Man version 3.14159, using POD::Parser version 1.92</pre>
<p>Formatters may also insert additional comments, including: the
release date of the Pod formatter program, the contact address for
the <code>author(s)</code> of the formatter, the current time, the name of input
file, the formatting options in effect, version of Perl used, etc.</p>
<p>Formatters may also choose to note errors/warnings as comments,
besides or instead of emitting them otherwise (as in messages to
STDERR, or <code>die</code>ing).</p>
</li>
<li>
<p>Pod parsers <em>may</em> emit warnings or error messages (``Unknown E code
E&lt;zslig&gt;!'') to STDERR (whether through printing to STDERR, or
<code>warn</code>ing/<code>carp</code>ing, or <code>die</code>ing/<code>croak</code>ing), but <em>must</em> allow
suppressing all such STDERR output, and instead allow an option for
reporting errors/warnings
in some other way, whether by triggering a callback, or noting errors
in some attribute of the document object, or some similarly unobtrusive
mechanism -- or even by appending a ``Pod Errors'' section to the end of
the parsed form of the document.</p>
</li>
<li>
<p>In cases of exceptionally aberrant documents, Pod parsers may abort the
parse.  Even then, using <code>die</code>ing/<code>croak</code>ing is to be avoided; where
possible, the parser library may simply close the input file
and add text like ``*** Formatting Aborted ***'' to the end of the
(partial) in-memory document.</p>
</li>
<li>
<p>In paragraphs where formatting codes (like E&lt;...&gt;, B&lt;...&gt;)
are understood (i.e., <em>not</em> verbatim paragraphs, but <em>including</em>
ordinary paragraphs, and command paragraphs that produce renderable
text, like ``=head1''), literal whitespace should generally be considered
``insignificant'', in that one literal space has the same meaning as any
(nonzero) number of literal spaces, literal newlines, and literal tabs
(as long as this produces no blank lines, since those would terminate
the paragraph).  Pod parsers should compact literal whitespace in each
processed paragraph, but may provide an option for overriding this
(since some processing tasks do not require it), or may follow
additional special rules (for example, specially treating
period-space-space or period-newline sequences).</p>
</li>
<li>
<p>Pod parsers should not, by default, try to coerce apostrophe (') and
quote (``) into smart quotes (little 9's, 66's, 99's, etc), nor try to
turn backtick (`) into anything else but a single backtick character
(distinct from an openquote character!), nor ''--`` into anything but
two minus signs.  They <em>must never</em> do any of those things to text
in C&lt;...&gt; formatting codes, and never <em>ever</em> to text in verbatim
paragraphs.</p>
</li>
<li>
<p>When rendering Pod to a format that has two kinds of hyphens (-), one
that's a non-breaking hyphen, and another that's a breakable hyphen
(as in ``object-oriented'', which can be split across lines as
``object-'', newline, ``oriented''), formatters are encouraged to
generally translate ``-'' to non-breaking hyphen, but may apply
heuristics to convert some of these to breaking hyphens.</p>
</li>
<li>
<p>Pod formatters should make reasonable efforts to keep words of Perl
code from being broken across lines.  For example, ``Foo::Bar'' in some
formatting systems is seen as eligible for being broken across lines
as ``Foo::'' newline ``Bar'' or even ``Foo::-'' newline ``Bar''.  This should
be avoided where possible, either by disabling all line-breaking in
mid-word, or by wrapping particular words with internal punctuation
in ``don't break this across lines'' codes (which in some formats may
not be a single code, but might be a matter of inserting non-breaking
zero-width spaces between every pair of characters in a word.)</p>
</li>
<li>
<p>Pod parsers should, by default, expand tabs in verbatim paragraphs as
they are processed, before passing them to the formatter or other
processor.  Parsers may also allow an option for overriding this.</p>
</li>
<li>
<p>Pod parsers should, by default, remove newlines from the end of
ordinary and verbatim paragraphs before passing them to the
formatter.  For example, while the paragraph you're reading now
could be considered, in Pod source, to end with (and contain)
the <code>newline(s)</code> that end it, it should be processed as ending with
(and containing) the period character that ends this sentence.</p>
</li>
<li>
<p>Pod parsers, when reporting errors, should make some effort to report
an approximate line number (``Nested E&lt;&gt;'s in Paragraph #52, near
line 633 of Thing/Foo.pm!''), instead of merely noting the paragraph
number (``Nested E&lt;&gt;'s in Paragraph #52 of Thing/Foo.pm!'').  Where
this is problematic, the paragraph number should at least be
accompanied by an excerpt from the paragraph (``Nested E&lt;&gt;'s in
Paragraph #52 of Thing/Foo.pm, which begins 'Read/write accessor for
the C&lt;interest rate&gt; attribute...''').</p>
</li>
<li>
<p>Pod parsers, when processing a series of verbatim paragraphs one
after another, should consider them to be one large verbatim
paragraph that happens to contain blank lines.  I.e., these two
lines, which have a blank line between them:</p>
<pre>
        use Foo;</pre>
<pre>
        print Foo-&gt;VERSION</pre>
<p>should be unified into one paragraph (``\tuse Foo;\n\n\tprint
Foo-&gt;VERSION'') before being passed to the formatter or other
processor.  Parsers may also allow an option for overriding this.</p>
<p>While this might be too cumbersome to implement in event-based Pod
parsers, it is straightforward for parsers that return parse trees.</p>
</li>
<li>
<p>Pod formatters, where feasible, are advised to avoid splitting short
verbatim paragraphs (under twelve lines, say) across pages.</p>
</li>
<li>
<p>Pod parsers must treat a line with only spaces and/or tabs on it as a
``blank line'' such as separates paragraphs.  (Some older parsers
recognized only two adjacent newlines as a ``blank line'' but would not
recognize a newline, a space, and a newline, as a blank line.  This
is noncompliant behavior.)</p>
</li>
<li>
<p>Authors of Pod formatters/processors should make every effort to
avoid writing their own Pod parser.  There are already several in
CPAN, with a wide range of interface styles -- and one of them,
Pod::Parser, comes with modern versions of Perl.</p>
</li>
<li>
<p>Characters in Pod documents may be conveyed either as literals, or by
number in E&lt;n&gt; codes, or by an equivalent mnemonic, as in
E&lt;eacute&gt; which is exactly equivalent to E&lt;233&gt;.</p>
<p>Characters in the range 32-126 refer to those well known US-ASCII
characters (also defined there by Unicode, with the same meaning),
which all Pod formatters must render faithfully.  Characters
in the ranges 0-31 and 127-159 should not be used (neither as
literals, nor as E&lt;number&gt; codes), except for the
literal byte-sequences for newline (13, 13 10, or 10), and tab (9).</p>
<p>Characters in the range 160-255 refer to Latin-1 characters (also
defined there by Unicode, with the same meaning).  Characters above
255 should be understood to refer to Unicode characters.</p>
</li>
<li>
<p>Be warned
that some formatters cannot reliably render characters outside 32-126;
and many are able to handle 32-126 and 160-255, but nothing above
255.</p>
</li>
<li>
<p>Besides the well-known ``E&lt;lt&gt;'' and ``E&lt;gt&gt;'' codes for
less-than and greater-than, Pod parsers must understand ``E&lt;sol&gt;''
for ``/'' (solidus, slash), and ``E&lt;verbar&gt;'' for ``|'' (vertical bar,
pipe).  Pod parsers should also understand ``E&lt;lchevron&gt;'' and
``E&lt;rchevron&gt;'' as legacy codes for characters 171 and 187, i.e.,
``left-pointing double angle quotation mark'' = ``left pointing
guillemet'' and ``right-pointing double angle quotation mark'' = ``right
pointing guillemet''.  (These look like little ``&lt;&lt;'' and ``&gt;&gt;'', and they
are now preferably expressed with the HTML/XHTML codes ``E&lt;laquo&gt;''
and ``E&lt;raquo&gt;''.)</p>
</li>
<li>
<p>Pod parsers should understand all ``E&lt;html&gt;'' codes as defined
in the entity declarations in the most recent XHTML specification at
<code>www.W3.org</code>.  Pod parsers must understand at least the entities
that define characters in the range 160-255 (Latin-1).  Pod parsers,
when faced with some unknown ``E&lt;<em>identifier</em>&gt;'' code,
shouldn't simply replace it with nullstring (by default, at least),
but may pass it through as a string consisting of the literal characters
E, less-than, <em>identifier</em>, greater-than.  Or Pod parsers may offer the
alternative option of processing such unknown
``E&lt;<em>identifier</em>&gt;'' codes by firing an event especially
for such codes, or by adding a special node-type to the in-memory
document tree.  Such ``E&lt;<em>identifier</em>&gt;'' may have special meaning
to some processors, or some processors may choose to add them to
a special error report.</p>
</li>
<li>
<p>Pod parsers must also support the XHTML codes ``E&lt;quot&gt;'' for
character 34 (doublequote, ``), ''E&lt;amp&gt;`` for character 38
(ampersand, &amp;), and ''E&lt;apos&gt;`` for character 39 (apostrophe, ').</p>
</li>
<li>
<p>Note that in all cases of ``E&lt;whatever&gt;'', <em>whatever</em> (whether
an htmlname, or a number in any base) must consist only of
alphanumeric characters -- that is, <em>whatever</em> must watch
<code>m/\A\w+\z/</code>.  So ``E&lt; 0 1 2 3 &gt;'' is invalid, because
it contains spaces, which aren't alphanumeric characters.  This
presumably does not <em>need</em> special treatment by a Pod processor;
`` 0 1 2 3 '' doesn't look like a number in any base, so it would
presumably be looked up in the table of HTML-like names.  Since
there isn't (and cannot be) an HTML-like entity called `` 0 1 2 3 '',
this will be treated as an error.  However, Pod processors may
treat ``E&lt; 0 1 2 3 &gt;'' or ``E&lt;e-acute&gt;'' as <em>syntactically</em>
invalid, potentially earning a different error message than the
error message (or warning, or event) generated by a merely unknown
(but theoretically valid) htmlname, as in ``E&lt;qacute&gt;''
[sic].  However, Pod parsers are not required to make this
distinction.</p>
</li>
<li>
<p>Note that E&lt;number&gt; <em>must not</em> be interpreted as simply
``codepoint <em>number</em> in the current/native character set''.  It always
means only ``the character represented by codepoint <em>number</em> in
Unicode.''  (This is identical to the semantics of &amp;#<em>number</em>; in XML.)</p>
<p>This will likely require many formatters to have tables mapping from
treatable Unicode codepoints (such as the ``\xE9'' for the e-acute
character) to the escape sequences or codes necessary for conveying
such sequences in the target output format.  A converter to *roff
would, for example know that ``\xE9'' (whether conveyed literally, or via
a E&lt;...&gt; sequence) is to be conveyed as ``e\\*'''.
Similarly, a program rendering Pod in a Mac OS application window, would
presumably need to know that ``\xE9'' maps to codepoint 142 in MacRoman
encoding that (at time of writing) is native for Mac OS.  Such
Unicode2whatever mappings are presumably already widely available for
common output formats.  (Such mappings may be incomplete!  Implementers
are not expected to bend over backwards in an attempt to render
Cherokee syllabics, Etruscan runes, Byzantine musical symbols, or any
of the other weird things that Unicode can encode.)  And
if a Pod document uses a character not found in such a mapping, the
formatter should consider it an unrenderable character.</p>
</li>
<li>
<p>If, surprisingly, the implementor of a Pod formatter can't find a
satisfactory pre-existing table mapping from Unicode characters to
escapes in the target format (e.g., a decent table of Unicode
characters to *roff escapes), it will be necessary to build such a
table.  If you are in this circumstance, you should begin with the
characters in the range 0x00A0 - 0x00FF, which is mostly the heavily
used accented characters.  Then proceed (as patience permits and
fastidiousness compels) through the characters that the (X)HTML
standards groups judged important enough to merit mnemonics
for.  These are declared in the (X)HTML specifications at the
www.W3.org site.  At time of writing (September 2001), the most recent
entity declaration files are:</p>
<pre>
  <a href="http://www.w3.org/TR/xhtml1/DTD/xhtml-lat1.ent">http://www.w3.org/TR/xhtml1/DTD/xhtml-lat1.ent</a>
  <a href="http://www.w3.org/TR/xhtml1/DTD/xhtml-special.ent">http://www.w3.org/TR/xhtml1/DTD/xhtml-special.ent</a>
  <a href="http://www.w3.org/TR/xhtml1/DTD/xhtml-symbol.ent">http://www.w3.org/TR/xhtml1/DTD/xhtml-symbol.ent</a></pre>
<p>Then you can progress through any remaining notable Unicode characters
in the range 0x2000-0x204D (consult the character tables at
www.unicode.org), and whatever else strikes your fancy.  For example,
in <em>xhtml-symbol.ent</em>, there is the entry:</p>
<pre>
  &lt;!ENTITY infin    &quot;&amp;#8734;&quot;&gt; &lt;!-- infinity, U+221E ISOtech --&gt;</pre>
<p>While the mapping ``infin'' to the character ``\x{221E}'' will (hopefully)
have been already handled by the Pod parser, the presence of the
character in this file means that it's reasonably important enough to
include in a formatter's table that maps from notable Unicode characters
to the codes necessary for rendering them.  So for a Unicode-to-*roff
mapping, for example, this would merit the entry:</p>
<pre>
  &quot;\x{221E}&quot; =&gt; '\(in',</pre>
<p>It is eagerly hoped that in the future, increasing numbers of formats
(and formatters) will support Unicode characters directly (as (X)HTML
does with <code>&amp;infin;</code>, <code>&amp;#8734;</code>, or <code>&amp;#x221E;</code>), reducing the need
for idiosyncratic mappings of Unicode-to-<em>my_escapes</em>.</p>
</li>
<li>
<p>It is up to individual Pod formatter to display good judgment when
confronted with an unrenderable character (which is distinct from an
unknown E&lt;thing&gt; sequence that the parser couldn't resolve to
anything, renderable or not).  It is good practice to map Latin letters
with diacritics (like ``E&lt;eacute&gt;''/``E&lt;233&gt;'') to the corresponding
unaccented US-ASCII letters (like a simple character 101, ``e''), but
clearly this is often not feasible, and an unrenderable character may
be represented as ``?'', or the like.  In attempting a sane fallback
(as from E&lt;233&gt; to ``e''), Pod formatters may use the
%Latin1Code_to_fallback table in <a href="../../Pod/Escapes.html">Pod::Escapes</a>, or
<a href="../../Text/Unidecode.html">Text::Unidecode</a>, if available.</p>
<p>For example, this Pod text:</p>
<pre>
  magic is enabled if you set C&lt;$Currency&gt; to 'E&lt;euro&gt;'.</pre>
<p>may be rendered as:
``magic is enabled if you set <code>$Currency</code> to '<em>?</em>''' or as
``magic is enabled if you set <code>$Currency</code> to '<strong>[euro]</strong>''', or as
``magic is enabled if you set <code>$Currency</code> to '[x20AC]', etc.</p>
<p>A Pod formatter may also note, in a comment or warning, a list of what
unrenderable characters were encountered.</p>
</li>
<li>
<p>E&lt;...&gt; may freely appear in any formatting code (other than
in another E&lt;...&gt; or in an Z&lt;&gt;).  That is, ``X&lt;The
E&lt;euro&gt;1,000,000 Solution&gt;'' is valid, as is ``L&lt;The
E&lt;euro&gt;1,000,000 Solution|Million::Euros&gt;''.</p>
</li>
<li>
<p>Some Pod formatters output to formats that implement non-breaking
spaces as an individual character (which I'll call ``NBSP''), and
others output to formats that implement non-breaking spaces just as
spaces wrapped in a ``don't break this across lines'' code.  Note that
at the level of Pod, both sorts of codes can occur: Pod can contain a
NBSP character (whether as a literal, or as a ``E&lt;160&gt;'' or
``E&lt;nbsp&gt;'' code); and Pod can contain ``S&lt;foo
I&lt;bar&gt; baz&gt;'' codes, where ``mere spaces'' (character 32) in
such codes are taken to represent non-breaking spaces.  Pod
parsers should consider supporting the optional parsing of ``S&lt;foo
I&lt;bar&gt; baz&gt;'' as if it were
``foo<em>NBSP</em>I&lt;bar&gt;<em>NBSP</em>baz'', and, going the other way, the
optional parsing of groups of words joined by NBSP's as if each group
were in a S&lt;...&gt; code, so that formatters may use the
representation that maps best to what the output format demands.</p>
</li>
<li>
<p>Some processors may find that the <code>S&lt;...&gt;</code> code is easiest to
implement by replacing each space in the parse tree under the content
of the S, with an NBSP.  But note: the replacement should apply <em>not</em> to
spaces in <em>all</em> text, but <em>only</em> to spaces in <em>printable</em> text.  (This
distinction may or may not be evident in the particular tree/event
model implemented by the Pod parser.)  For example, consider this
unusual case:</p>
<pre>
   S&lt;L&lt;/Autoloaded Functions&gt;&gt;</pre>
<p>This means that the space in the middle of the visible link text must
not be broken across lines.  In other words, it's the same as this:</p>
<pre>
   L&lt;&quot;AutoloadedE&lt;160&gt;Functions&quot;/Autoloaded Functions&gt;</pre>
<p>However, a misapplied space-to-NBSP replacement could (wrongly)
produce something equivalent to this:</p>
<pre>
   L&lt;&quot;AutoloadedE&lt;160&gt;Functions&quot;/AutoloadedE&lt;160&gt;Functions&gt;</pre>
<p>...which is almost definitely not going to work as a hyperlink (assuming
this formatter outputs a format supporting hypertext).</p>
<p>Formatters may choose to just not support the S format code,
especially in cases where the output format simply has no NBSP
character/code and no code for ``don't break this stuff across lines''.</p>
</li>
<li>
<p>Besides the NBSP character discussed above, implementors are reminded
of the existence of the other ``special'' character in Latin-1, the
``soft hyphen'' character, also known as ``discretionary hyphen'',
i.e. <code>E&lt;173&gt;</code> = <code>E&lt;0xAD&gt;</code> =
<code>E&lt;shy&gt;</code>).  This character expresses an optional hyphenation
point.  That is, it normally renders as nothing, but may render as a
``-'' if a formatter breaks the word at that point.  Pod formatters
should, as appropriate, do one of the following:  1) render this with
a code with the same meaning (e.g., ``\-'' in RTF), 2) pass it through
in the expectation that the formatter understands this character as
such, or 3) delete it.</p>
<p>For example:</p>
<pre>
  sigE&lt;shy&gt;action
  manuE&lt;shy&gt;script
  JarkE&lt;shy&gt;ko HieE&lt;shy&gt;taE&lt;shy&gt;nieE&lt;shy&gt;mi</pre>
<p>These signal to a formatter that if it is to hyphenate ``sigaction''
or ``manuscript'', then it should be done as
``sig-<em>[linebreak]</em>action'' or ``manu-<em>[linebreak]</em>script''
(and if it doesn't hyphenate it, then the <code>E&lt;shy&gt;</code> doesn't
show up at all).  And if it is
to hyphenate ``Jarkko'' and/or ``Hietaniemi'', it can do
so only at the points where there is a <code>E&lt;shy&gt;</code> code.</p>
<p>In practice, it is anticipated that this character will not be used
often, but formatters should either support it, or delete it.</p>
</li>
<li>
<p>If you think that you want to add a new command to Pod (like, say, a
``=biblio'' command), consider whether you could get the same
effect with a for or begin/end sequence: ``=for biblio ...'' or ``=begin
biblio'' ... ``=end biblio''.  Pod processors that don't understand
``=for biblio'', etc, will simply ignore it, whereas they may complain
loudly if they see ``=biblio''.</p>
</li>
<li>
<p>Throughout this document, ``Pod'' has been the preferred spelling for
the name of the documentation format.  One may also use ``POD'' or
``pod''.  For the documentation that is (typically) in the Pod
format, you may use ``pod'', or ``Pod'', or ``POD''.  Understanding these
distinctions is useful; but obsessing over how to spell them, usually
is not.</p>
</li>
</ul>
<p>
</p>
<hr />
<h1><a name="about_l______codes">About L&lt;...&gt; Codes</a></h1>
<p>As you can tell from a glance at <a href="perlpod.html">perlpod</a>, the L&lt;...&gt;
code is the most complex of the Pod formatting codes.  The points below
will hopefully clarify what it means and how processors should deal
with it.</p>
<ul>
<li>
<p>In parsing an L&lt;...&gt; code, Pod parsers must distinguish at least
four attributes:</p>
<dl>
<dt><strong><a name="item_first_3a">First:</a></strong>

<dd>
<p>The link-text.  If there is none, this must be undef.  (E.g., in
``L&lt;Perl Functions|perlfunc&gt;'', the link-text is ``Perl Functions''.
In ``L&lt;Time::HiRes&gt;'' and even ``L&lt;|Time::HiRes&gt;'', there is no
link text.  Note that link text may contain formatting.)</p>
</dd>
</li>
<dt><strong><a name="item_second_3a">Second:</a></strong>

<dd>
<p>The possibly inferred link-text -- i.e., if there was no real link
text, then this is the text that we'll infer in its place.  (E.g., for
``L&lt;Getopt::Std&gt;'', the inferred link text is ``Getopt::Std''.)</p>
</dd>
</li>
<dt><strong><a name="item_third_3a">Third:</a></strong>

<dd>
<p>The name or URL, or undef if none.  (E.g., in ``L&lt;Perl
Functions|perlfunc&gt;'', the name -- also sometimes called the page --
is ``perlfunc''.  In ``L&lt;/CAVEATS&gt;'', the name is undef.)</p>
</dd>
</li>
<dt><strong><a name="item_fourth_3a">Fourth:</a></strong>

<dd>
<p>The section (AKA ``item'' in older perlpods), or undef if none.  E.g.,
in <a href="../../Getopt/Std.html#description">DESCRIPTION in the Getopt::Std manpage</a>, ``DESCRIPTION'' is the section.  (Note
that this is not the same as a manpage section like the ``5'' in ``man 5
crontab''.  ``Section Foo'' in the Pod sense means the part of the text
that's introduced by the heading or item whose text is ``Foo''.)</p>
</dd>
</li>
</dl>
<p>Pod parsers may also note additional attributes including:</p>
<dl>
<dt><strong><a name="item_fifth_3a">Fifth:</a></strong>

<dd>
<p>A flag for whether item 3 (if present) is a URL (like
``http://lists.perl.org'' is), in which case there should be no section
attribute; a Pod name (like ``perldoc'' and ``Getopt::Std'' are); or
possibly a man page name (like ``crontab(5)'' is).</p>
</dd>
</li>
<dt><strong><a name="item_sixth_3a">Sixth:</a></strong>

<dd>
<p>The raw original L&lt;...&gt; content, before text is split on
``|'', ``/'', etc, and before E&lt;...&gt; codes are expanded.</p>
</dd>
</li>
</dl>
<p>(The above were numbered only for concise reference below.  It is not
a requirement that these be passed as an actual list or array.)</p>
<p>For example:</p>
<pre>
  L&lt;Foo::Bar&gt;
    =&gt;  undef,                          # link text
        &quot;Foo::Bar&quot;,                     # possibly inferred link text
        &quot;Foo::Bar&quot;,                     # name
        undef,                          # section
        'pod',                          # what sort of link
        &quot;Foo::Bar&quot;                      # original content</pre>
<pre>
  L&lt;Perlport's section on NL's|<a href="perlport.html">perlport</a>/Newlines&gt;
    =&gt;  &quot;Perlport's section on NL's&quot;,   # link text
        &quot;Perlport's section on NL's&quot;,   # possibly inferred link text
        &quot;<a href="perlport.html">perlport</a>&quot;,                     # name
        &quot;Newlines&quot;,                     # section
        'pod',                          # what sort of link
        &quot;Perlport's section on NL's|<a href="perlport.html">perlport</a>/Newlines&quot; # orig. content</pre>
<pre>
  L&lt;<a href="perlport.html">perlport</a>/Newlines&gt;
    =&gt;  undef,                          # link text
        '&quot;Newlines&quot; in <a href="perlport.html">perlport</a>',       # possibly inferred link text
        &quot;<a href="perlport.html">perlport</a>&quot;,                     # name
        &quot;Newlines&quot;,                     # section
        'pod',                          # what sort of link
        &quot;<a href="perlport.html">perlport</a>/Newlines&quot;             # original content</pre>
<pre>
  L&lt;crontab(5)/&quot;DESCRIPTION&quot;&gt;
    =&gt;  undef,                          # link text
        '&quot;DESCRIPTION&quot; in crontab(5)',  # possibly inferred link text
        &quot;crontab(5)&quot;,                   # name
        &quot;DESCRIPTION&quot;,                  # section
        'man',                          # what sort of link
        'crontab(5)/&quot;DESCRIPTION&quot;'      # original content</pre>
<pre>
  L&lt;/Object Attributes&gt;
    =&gt;  undef,                          # link text
        '&quot;Object Attributes&quot;',          # possibly inferred link text
        undef,                          # name
        &quot;Object Attributes&quot;,            # section
        'pod',                          # what sort of link
        &quot;/Object Attributes&quot;            # original content</pre>
<pre>
  L&lt;<a href="http://www.perl.org/&gt">http://www.perl.org/&gt</a>;
    =&gt;  undef,                          # link text
        &quot;<a href="http://www.perl.org/&quot">http://www.perl.org/&quot</a>;,         # possibly inferred link text
        &quot;<a href="http://www.perl.org/&quot">http://www.perl.org/&quot</a>;,         # name
        undef,                          # section
        'url',                          # what sort of link
        &quot;<a href="http://www.perl.org/&quot">http://www.perl.org/&quot</a>;          # original content</pre>
<p>Note that you can distinguish URL-links from anything else by the
fact that they match <code>m/\A\w+:[^:\s]\S*\z/</code>.  So
<code>L&lt;http://www.perl.com&gt;</code> is a URL, but
<code>L&lt;HTTP::Response&gt;</code> isn't.</p>
<li>
<p>In case of L&lt;...&gt; codes with no ``text|'' part in them,
older formatters have exhibited great variation in actually displaying
the link or cross reference.  For example, L&lt;crontab(5)&gt; would render
as ``the <code>crontab(5)</code> manpage'', or ``in the <code>crontab(5)</code> manpage''
or just ``<code>crontab(5)</code>''.</p>
<p>Pod processors must now treat ``text|''-less links as follows:</p>
<pre>
  L&lt;name&gt;         =&gt;  L&lt;name|name&gt;
  L&lt;/section&gt;     =&gt;  L&lt;&quot;section&quot;|/section&gt;
  L&lt;name/section&gt; =&gt;  L&lt;&quot;section&quot; in name|name/section&gt;</pre>
</li>
<li>
<p>Note that section names might contain markup.  I.e., if a section
starts with:</p>
<pre>
  =head2 About the C&lt;-M&gt; Operator</pre>
<p>or with:</p>
<pre>
  =item About the C&lt;-M&gt; Operator</pre>
<p>then a link to it would look like this:</p>
<pre>
  L&lt;somedoc/About the C&lt;-M&gt; Operator&gt;</pre>
<p>Formatters may choose to ignore the markup for purposes of resolving
the link and use only the renderable characters in the section name,
as in:</p>
<pre>
  &lt;h1&gt;&lt;a name=&quot;About_the_-M_Operator&quot;&gt;About the &lt;code&gt;-M&lt;/code&gt;
  Operator&lt;/h1&gt;</pre>
<pre>
  ...</pre>
<pre>
  &lt;a href=&quot;somedoc#About_the_-M_Operator&quot;&gt;About the &lt;code&gt;-M&lt;/code&gt;
  Operator&quot; in somedoc&lt;/a&gt;</pre>
</li>
<li>
<p>Previous versions of perlpod distinguished <code>L&lt;name/&quot;section&quot;&gt;</code>
links from <code>L&lt;name/item&gt;</code> links (and their targets).  These
have been merged syntactically and semantically in the current
specification, and <em>section</em> can refer either to a ``=head<em>n</em> Heading
Content'' command or to a ``=item Item Content'' command.  This
specification does not specify what behavior should be in the case
of a given document having several things all seeming to produce the
same <em>section</em> identifier (e.g., in HTML, several things all producing
the same <em>anchorname</em> in &lt;a name=``<em>anchorname</em>''&gt;...&lt;/a&gt;
elements).  Where Pod processors can control this behavior, they should
use the first such anchor.  That is, <code>L&lt;Foo/Bar&gt;</code> refers to the
<em>first</em> ``Bar'' section in Foo.</p>
<p>But for some processors/formats this cannot be easily controlled; as
with the HTML example, the behavior of multiple ambiguous
&lt;a name=``<em>anchorname</em>''&gt;...&lt;/a&gt; is most easily just left up to
browsers to decide.</p>
</li>
<li>
<p>Authors wanting to link to a particular (absolute) URL, must do so
only with ``L&lt;scheme:...&gt;'' codes (like
L&lt;<a href="http://www.perl.org>">http://www.perl.org></a>), and must not attempt ``L&lt;Some Site
Name|scheme:...&gt;'' codes.  This restriction avoids many problems
in parsing and rendering L&lt;...&gt; codes.</p>
</li>
<li>
<p>In a <code>L&lt;text|...&gt;</code> code, text may contain formatting codes
for formatting or for E&lt;...&gt; escapes, as in:</p>
<pre>
  L&lt;B&lt;ummE&lt;234&gt;stuff&gt;|...&gt;</pre>
<p>For <code>L&lt;...&gt;</code> codes without a ``name|'' part, only
<code>E&lt;...&gt;</code> and <code>Z&lt;&gt;</code> codes may occur -- no
other formatting codes.  That is, authors should not use
``<code>L&lt;B&lt;Foo::Bar&gt;&gt;</code>''.</p>
<p>Note, however, that formatting codes and Z&lt;&gt;'s can occur in any
and all parts of an L&lt;...&gt; (i.e., in <em>name</em>, <em>section</em>, <em>text</em>,
and <em>url</em>).</p>
<p>Authors must not nest L&lt;...&gt; codes.  For example, ``L&lt;The
L&lt;Foo::Bar&gt; man page&gt;'' should be treated as an error.</p>
</li>
<li>
<p>Note that Pod authors may use formatting codes inside the ``text''
part of ``L&lt;text|name&gt;'' (and so on for L&lt;text|/``sec''&gt;).</p>
<p>In other words, this is valid:</p>
<pre>
  Go read L&lt;the docs on C&lt;$.&gt;|<a href="perlvar.html">perlvar</a>/&quot;$.&quot;&gt;</pre>
<p>Some output formats that do allow rendering ``L&lt;...&gt;'' codes as
hypertext, might not allow the link-text to be formatted; in
that case, formatters will have to just ignore that formatting.</p>
</li>
<li>
<p>At time of writing, <code>L&lt;name&gt;</code> values are of two types:
either the name of a Pod page like <code>L&lt;Foo::Bar&gt;</code> (which
might be a real Perl module or program in an @INC / PATH
directory, or a .pod file in those places); or the name of a UNIX
man page, like <code>L&lt;crontab(5)&gt;</code>.  In theory, <code>L&lt;chmod&gt;</code>
in ambiguous between a Pod page called ``chmod'', or the Unix man page
``chmod'' (in whatever man-section).  However, the presence of a string
in parens, as in ``crontab(5)'', is sufficient to signal that what
is being discussed is not a Pod page, and so is presumably a
UNIX man page.  The distinction is of no importance to many
Pod processors, but some processors that render to hypertext formats
may need to distinguish them in order to know how to render a
given <code>L&lt;foo&gt;</code> code.</p>
</li>
<li>
<p>Previous versions of perlpod allowed for a <code>L&lt;section&gt;</code> syntax
(as in ``<code>L&lt;Object Attributes&gt;</code>''), which was not easily distinguishable
from <code>L&lt;name&gt;</code> syntax.  This syntax is no longer in the
specification, and has been replaced by the <code>L&lt;&quot;section&quot;&gt;</code> syntax
(where the quotes were formerly optional).  Pod parsers should tolerate
the <code>L&lt;section&gt;</code> syntax, for a while at least.  The suggested
heuristic for distinguishing <code>L&lt;section&gt;</code> from <code>L&lt;name&gt;</code>
is that if it contains any whitespace, it's a <em>section</em>.  Pod processors
may warn about this being deprecated syntax.</p>
</li>
</ul>
<p>
</p>
<hr />
<h1><a name="about__over____back_regions">About =over...=back Regions</a></h1>
<p>``=over''...``=back'' regions are used for various kinds of list-like
structures.  (I use the term ``region'' here simply as a collective
term for everything from the ``=over'' to the matching ``=back''.)</p>
<ul>
<li>
<p>The non-zero numeric <em>indentlevel</em> in ``=over <em>indentlevel</em>'' ...
``=back'' is used for giving the formatter a clue as to how many
``spaces'' (ems, or roughly equivalent units) it should tab over,
although many formatters will have to convert this to an absolute
measurement that may not exactly match with the size of spaces (or M's)
in the document's base font.  Other formatters may have to completely
ignore the number.  The lack of any explicit <em>indentlevel</em> parameter is
equivalent to an <em>indentlevel</em> value of 4.  Pod processors may
complain if <em>indentlevel</em> is present but is not a positive number
matching <code>m/\A(\d*\.)?\d+\z/</code>.</p>
</li>
<li>
<p>Authors of Pod formatters are reminded that ``=over'' ... ``=back'' may
map to several different constructs in your output format.  For
example, in converting Pod to (X)HTML, it can map to any of
&lt;ul&gt;...&lt;/ul&gt;, &lt;ol&gt;...&lt;/ol&gt;, &lt;dl&gt;...&lt;/dl&gt;, or
&lt;blockquote&gt;...&lt;/blockquote&gt;.  Similarly, ``=item'' can map to &lt;li&gt; or
&lt;dt&gt;.</p>
</li>
<li>
<p>Each ``=over'' ... ``=back'' region should be one of the following:</p>
<ul>
<li>
<p>An ``=over'' ... ``=back'' region containing only ``=item *'' commands,
each followed by some number of ordinary/verbatim paragraphs, other
nested ``=over'' ... ``=back'' regions, ``=for...'' paragraphs, and
``=begin''...``=end'' regions.</p>
<p>(Pod processors must tolerate a bare ``=item'' as if it were ``=item
*''.)  Whether ``*'' is rendered as a literal asterisk, an ``o'', or as
some kind of real bullet character, is left up to the Pod formatter,
and may depend on the level of nesting.</p>
</li>
<li>
<p>An ``=over'' ... ``=back'' region containing only
<code>m/\A=item\s+\d+\.?\s*\z/</code> paragraphs, each one (or each group of them)
followed by some number of ordinary/verbatim paragraphs, other nested
``=over'' ... ``=back'' regions, ``=for...'' paragraphs, and/or
``=begin''...``=end'' codes.  Note that the numbers must start at 1
in each section, and must proceed in order and without skipping
numbers.</p>
<p>(Pod processors must tolerate lines like ``=item 1'' as if they were
``=item 1.'', with the period.)</p>
</li>
<li>
<p>An ``=over'' ... ``=back'' region containing only ``=item [text]''
commands, each one (or each group of them) followed by some number of
ordinary/verbatim paragraphs, other nested ``=over'' ... ``=back''
regions, or ``=for...'' paragraphs, and ``=begin''...``=end'' regions.</p>
<p>The ``=item [text]'' paragraph should not match
<code>m/\A=item\s+\d+\.?\s*\z/</code> or <code>m/\A=item\s+\*\s*\z/</code>, nor should it
match just <code>m/\A=item\s*\z/</code>.</p>
</li>
<li>
<p>An ``=over'' ... ``=back'' region containing no ``=item'' paragraphs at
all, and containing only some number of 
ordinary/verbatim paragraphs, and possibly also some nested ``=over''
... ``=back'' regions, ``=for...'' paragraphs, and ``=begin''...``=end''
regions.  Such an itemless ``=over'' ... ``=back'' region in Pod is
equivalent in meaning to a ``&lt;blockquote&gt;...&lt;/blockquote&gt;'' element in
HTML.</p>
</li>
</ul>
<p>Note that with all the above cases, you can determine which type of
``=over'' ... ``=back'' you have, by examining the first (non-``=cut'', 
non-``=pod'') Pod paragraph after the ``=over'' command.</p>
<li>
<p>Pod formatters <em>must</em> tolerate arbitrarily large amounts of text
in the ``=item <em>text...</em>'' paragraph.  In practice, most such
paragraphs are short, as in:</p>
<pre>
  =item For cutting off our trade with all parts of the world</pre>
<p>But they may be arbitrarily long:</p>
<pre>
  =item For transporting us beyond seas to be tried for pretended
  offenses</pre>
<pre>
  =item He is at this time transporting large armies of foreign
  mercenaries to complete the works of death, desolation and
  tyranny, already begun with circumstances of cruelty and perfidy
  scarcely paralleled in the most barbarous ages, and totally
  unworthy the head of a civilized nation.</pre>
</li>
<li>
<p>Pod processors should tolerate ``=item *'' / ``=item <em>number</em>'' commands
with no accompanying paragraph.  The middle item is an example:</p>
<pre>
  =over</pre>
<pre>
  =item 1</pre>
<pre>
  Pick up dry cleaning.</pre>
<pre>
  =item 2</pre>
<pre>
  =item 3</pre>
<pre>
  Stop by the store.  Get Abba Zabas, Stoli, and cheap lawn chairs.</pre>
<pre>
  =back</pre>
</li>
<li>
<p>No ``=over'' ... ``=back'' region can contain headings.  Processors may
treat such a heading as an error.</p>
</li>
<li>
<p>Note that an ``=over'' ... ``=back'' region should have some
content.  That is, authors should not have an empty region like this:</p>
<pre>
  =over</pre>
<pre>
  =back</pre>
<p>Pod processors seeing such a contentless ``=over'' ... ``=back'' region,
may ignore it, or may report it as an error.</p>
</li>
<li>
<p>Processors must tolerate an ``=over'' list that goes off the end of the
document (i.e., which has no matching ``=back''), but they may warn
about such a list.</p>
</li>
<li>
<p>Authors of Pod formatters should note that this construct:</p>
<pre>
  =item Neque</pre>
<pre>
  =item Porro</pre>
<pre>
  =item Quisquam Est</pre>
<pre>
  Qui dolorem ipsum quia dolor sit amet, consectetur, adipisci 
  velit, sed quia non numquam eius modi tempora incidunt ut
  labore et dolore magnam aliquam quaerat voluptatem.</pre>
<pre>
  =item Ut Enim</pre>
<p>is semantically ambiguous, in a way that makes formatting decisions
a bit difficult.  On the one hand, it could be mention of an item
``Neque'', mention of another item ``Porro'', and mention of another
item ``Quisquam Est'', with just the last one requiring the explanatory
paragraph ``Qui dolorem ipsum quia dolor...''; and then an item
``Ut Enim''.  In that case, you'd want to format it like so:</p>
<pre>
  Neque</pre>
<pre>
  Porro</pre>
<pre>
  Quisquam Est
    Qui dolorem ipsum quia dolor sit amet, consectetur, adipisci
    velit, sed quia non numquam eius modi tempora incidunt ut
    labore et dolore magnam aliquam quaerat voluptatem.</pre>
<pre>
  Ut Enim</pre>
<p>But it could equally well be a discussion of three (related or equivalent)
items, ``Neque'', ``Porro'', and ``Quisquam Est'', followed by a paragraph
explaining them all, and then a new item ``Ut Enim''.  In that case, you'd
probably want to format it like so:</p>
<pre>
  Neque
  Porro
  Quisquam Est
    Qui dolorem ipsum quia dolor sit amet, consectetur, adipisci
    velit, sed quia non numquam eius modi tempora incidunt ut
    labore et dolore magnam aliquam quaerat voluptatem.</pre>
<pre>
  Ut Enim</pre>
<p>But (for the forseeable future), Pod does not provide any way for Pod
authors to distinguish which grouping is meant by the above
``=item''-cluster structure.  So formatters should format it like so:</p>
<pre>
  Neque</pre>
<pre>
  Porro</pre>
<pre>
  Quisquam Est</pre>
<pre>
    Qui dolorem ipsum quia dolor sit amet, consectetur, adipisci
    velit, sed quia non numquam eius modi tempora incidunt ut
    labore et dolore magnam aliquam quaerat voluptatem.</pre>
<pre>
  Ut Enim</pre>
<p>That is, there should be (at least roughly) equal spacing between
items as between paragraphs (although that spacing may well be less
than the full height of a line of text).  This leaves it to the reader
to use (con)textual cues to figure out whether the ``Qui dolorem
ipsum...'' paragraph applies to the ``Quisquam Est'' item or to all three
items ``Neque'', ``Porro'', and ``Quisquam Est''.  While not an ideal
situation, this is preferable to providing formatting cues that may
be actually contrary to the author's intent.</p>
</li>
</ul>
<p>
</p>
<hr />
<h1><a name="about_data_paragraphs_and__begin__end_regions">About Data Paragraphs and ``=begin/=end'' Regions</a></h1>
<p>Data paragraphs are typically used for inlining non-Pod data that is
to be used (typically passed through) when rendering the document to
a specific format:</p>
<pre>
  =begin rtf</pre>
<pre>
  \par{\pard\qr\sa4500{\i Printed\~\chdate\~\chtime}\par}</pre>
<pre>
  =end rtf</pre>
<p>The exact same effect could, incidentally, be achieved with a single
``=for'' paragraph:</p>
<pre>
  =for rtf \par{\pard\qr\sa4500{\i Printed\~\chdate\~\chtime}\par}</pre>
<p>(Although that is not formally a data paragraph, it has the same
meaning as one, and Pod parsers may parse it as one.)</p>
<p>Another example of a data paragraph:</p>
<pre>
  =begin html</pre>
<pre>
  I like &lt;em&gt;PIE&lt;/em&gt;!</pre>
<pre>
  &lt;hr&gt;Especially pecan pie!</pre>
<pre>
  =end html</pre>
<p>If these were ordinary paragraphs, the Pod parser would try to
expand the ``E&lt;/em&gt;'' (in the first paragraph) as a formatting
code, just like ``E&lt;lt&gt;'' or ``E&lt;eacute&gt;''.  But since this
is in a ``=begin <em>identifier</em>''...``=end <em>identifier</em>'' region <em>and</em>
the identifier ``html'' doesn't begin have a ``:'' prefix, the contents
of this region are stored as data paragraphs, instead of being
processed as ordinary paragraphs (or if they began with a spaces
and/or tabs, as verbatim paragraphs).</p>
<p>As a further example: At time of writing, no ``biblio'' identifier is
supported, but suppose some processor were written to recognize it as
a way of (say) denoting a bibliographic reference (necessarily
containing formatting codes in ordinary paragraphs).  The fact that
``biblio'' paragraphs were meant for ordinary processing would be
indicated by prefacing each ``biblio'' identifier with a colon:</p>
<pre>
  =begin :biblio</pre>
<pre>
  Wirth, Niklaus.  1976.  I&lt;Algorithms + Data Structures =
  Programs.&gt;  Prentice-Hall, Englewood Cliffs, NJ.</pre>
<pre>
  =end :biblio</pre>
<p>This would signal to the parser that paragraphs in this begin...end
region are subject to normal handling as ordinary/verbatim paragraphs
(while still tagged as meant only for processors that understand the
``biblio'' identifier).  The same effect could be had with:</p>
<pre>
  =for :biblio
  Wirth, Niklaus.  1976.  I&lt;Algorithms + Data Structures =
  Programs.&gt;  Prentice-Hall, Englewood Cliffs, NJ.</pre>
<p>The ``:'' on these identifiers means simply ``process this stuff
normally, even though the result will be for some special target''.
I suggest that parser APIs report ``biblio'' as the target identifier,
but also report that it had a ``:'' prefix.  (And similarly, with the
above ``html'', report ``html'' as the target identifier, and note the
<em>lack</em> of a ``:'' prefix.)</p>
<p>Note that a ``=begin <em>identifier</em>''...``=end <em>identifier</em>'' region where
<em>identifier</em> begins with a colon, <em>can</em> contain commands.  For example:</p>
<pre>
  =begin :biblio</pre>
<pre>
  Wirth's classic is available in several editions, including:</pre>
<pre>
  =for comment
   hm, check abebooks.com for how much used copies cost.</pre>
<pre>
  =over</pre>
<pre>
  =item</pre>
<pre>
  Wirth, Niklaus.  1975.  I&lt;Algorithmen und Datenstrukturen.&gt;
  Teubner, Stuttgart.  [Yes, it's in German.]</pre>
<pre>
  =item</pre>
<pre>
  Wirth, Niklaus.  1976.  I&lt;Algorithms + Data Structures =
  Programs.&gt;  Prentice-Hall, Englewood Cliffs, NJ.</pre>
<pre>
  =back</pre>
<pre>
  =end :biblio</pre>
<p>Note, however, a ``=begin <em>identifier</em>''...``=end <em>identifier</em>''
region where <em>identifier</em> does <em>not</em> begin with a colon, should not
directly contain ``=head1'' ... ``=head4'' commands, nor ``=over'', nor ``=back'',
nor ``=item''.  For example, this may be considered invalid:</p>
<pre>
  =begin somedata</pre>
<pre>
  This is a data paragraph.</pre>
<pre>
  =head1 Don't do this!</pre>
<pre>
  This is a data paragraph too.</pre>
<pre>
  =end somedata</pre>
<p>A Pod processor may signal that the above (specifically the ``=head1''
paragraph) is an error.  Note, however, that the following should
<em>not</em> be treated as an error:</p>
<pre>
  =begin somedata</pre>
<pre>
  This is a data paragraph.</pre>
<pre>
  =cut</pre>
<pre>
  # Yup, this isn't Pod anymore.
  sub excl { (rand() &gt; .5) ? &quot;hoo!&quot; : &quot;hah!&quot; }</pre>
<pre>
  =pod</pre>
<pre>
  This is a data paragraph too.</pre>
<pre>
  =end somedata</pre>
<p>And this too is valid:</p>
<pre>
  =begin someformat</pre>
<pre>
  This is a data paragraph.</pre>
<pre>
    And this is a data paragraph.</pre>
<pre>
  =begin someotherformat</pre>
<pre>
  This is a data paragraph too.</pre>
<pre>
    And this is a data paragraph too.</pre>
<pre>
  =begin :yetanotherformat</pre>
<pre>
  =head2 This is a command paragraph!</pre>
<pre>
  This is an ordinary paragraph!</pre>
<pre>
    And this is a verbatim paragraph!</pre>
<pre>
  =end :yetanotherformat</pre>
<pre>
  =end someotherformat</pre>
<pre>
  Another data paragraph!</pre>
<pre>
  =end someformat</pre>
<p>The contents of the above ``=begin :yetanotherformat'' ...
``=end :yetanotherformat'' region <em>aren't</em> data paragraphs, because
the immediately containing region's identifier (``:yetanotherformat'')
begins with a colon.  In practice, most regions that contain
data paragraphs will contain <em>only</em> data paragraphs; however, 
the above nesting is syntactically valid as Pod, even if it is
rare.  However, the handlers for some formats, like ``html'',
will accept only data paragraphs, not nested regions; and they may
complain if they see (targeted for them) nested regions, or commands,
other than ``=end'', ``=pod'', and ``=cut''.</p>
<p>Also consider this valid structure:</p>
<pre>
  =begin :biblio</pre>
<pre>
  Wirth's classic is available in several editions, including:</pre>
<pre>
  =over</pre>
<pre>
  =item</pre>
<pre>
  Wirth, Niklaus.  1975.  I&lt;Algorithmen und Datenstrukturen.&gt;
  Teubner, Stuttgart.  [Yes, it's in German.]</pre>
<pre>
  =item</pre>
<pre>
  Wirth, Niklaus.  1976.  I&lt;Algorithms + Data Structures =
  Programs.&gt;  Prentice-Hall, Englewood Cliffs, NJ.</pre>
<pre>
  =back</pre>
<pre>
  Buy buy buy!</pre>
<pre>
  =begin html</pre>
<pre>
  &lt;img src='wirth_spokesmodeling_book.png'&gt;</pre>
<pre>
  &lt;hr&gt;</pre>
<pre>
  =end html</pre>
<pre>
  Now now now!</pre>
<pre>
  =end :biblio</pre>
<p>There, the ``=begin html''...``=end html'' region is nested inside
the larger ``=begin :biblio''...``=end :biblio'' region.  Note that the
content of the ``=begin html''...``=end html'' region is data
paragraph(s), because the immediately containing region's identifier
(``html'') <em>doesn't</em> begin with a colon.</p>
<p>Pod parsers, when processing a series of data paragraphs one
after another (within a single region), should consider them to
be one large data paragraph that happens to contain blank lines.  So
the content of the above ``=begin html''...``=end html'' <em>may</em> be stored
as two data paragraphs (one consisting of
``&lt;img src='wirth_spokesmodeling_book.png'&gt;\n''
and another consisting of ``&lt;hr&gt;\n''), but <em>should</em> be stored as
a single data paragraph (consisting of 
``&lt;img src='wirth_spokesmodeling_book.png'&gt;\n\n&lt;hr&gt;\n'').</p>
<p>Pod processors should tolerate empty
``=begin <em>something</em>''...``=end <em>something</em>'' regions,
empty ``=begin :<em>something</em>''...``=end :<em>something</em>'' regions, and
contentless ``=for <em>something</em>'' and ``=for :<em>something</em>''
paragraphs.  I.e., these should be tolerated:</p>
<pre>
  =for html</pre>
<pre>
  =begin html</pre>
<pre>
  =end html</pre>
<pre>
  =begin :biblio</pre>
<pre>
  =end :biblio</pre>
<p>Incidentally, note that there's no easy way to express a data
paragraph starting with something that looks like a command.  Consider:</p>
<pre>
  =begin stuff</pre>
<pre>
  =shazbot</pre>
<pre>
  =end stuff</pre>
<p>There, ``=shazbot'' will be parsed as a Pod command ``shazbot'', not as a data
paragraph ``=shazbot\n''.  However, you can express a data paragraph consisting
of ``=shazbot\n'' using this code:</p>
<pre>
  =for stuff =shazbot</pre>
<p>The situation where this is necessary, is presumably quite rare.</p>
<p>Note that =end commands must match the currently open =begin command.  That
is, they must properly nest.  For example, this is valid:</p>
<pre>
  =begin outer</pre>
<pre>
  X</pre>
<pre>
  =begin inner</pre>
<pre>
  Y</pre>
<pre>
  =end inner</pre>
<pre>
  Z</pre>
<pre>
  =end outer</pre>
<p>while this is invalid:</p>
<pre>
  =begin outer</pre>
<pre>
  X</pre>
<pre>
  =begin inner</pre>
<pre>
  Y</pre>
<pre>
  =end outer</pre>
<pre>
  Z</pre>
<pre>
  =end inner</pre>
<p>This latter is improper because when the ``=end outer'' command is seen, the
currently open region has the formatname ``inner'', not ``outer''.  (It just
happens that ``outer'' is the format name of a higher-up region.)  This is
an error.  Processors must by default report this as an error, and may halt
processing the document containing that error.  A corollary of this is that
regions cannot ``overlap'' -- i.e., the latter block above does not represent
a region called ``outer'' which contains X and Y, overlapping a region called
``inner'' which contains Y and Z.  But because it is invalid (as all
apparently overlapping regions would be), it doesn't represent that, or
anything at all.</p>
<p>Similarly, this is invalid:</p>
<pre>
  =begin thing</pre>
<pre>
  =end hting</pre>
<p>This is an error because the region is opened by ``thing'', and the ``=end''
tries to close ``hting'' [sic].</p>
<p>This is also invalid:</p>
<pre>
  =begin thing</pre>
<pre>
  =end</pre>
<p>This is invalid because every ``=end'' command must have a formatname
parameter.</p>
<p>
</p>
<hr />
<h1><a name="see_also">SEE ALSO</a></h1>
<p><a href="perlpod.html">the perlpod manpage</a>, <a href="perlsyn.html#pods__embedded_documentation">PODs: Embedded Documentation in the perlsyn manpage</a>,
<a href="podchecker.html">the podchecker manpage</a></p>
<p>
</p>
<hr />
<h1><a name="author">AUTHOR</a></h1>
<p>Sean M. Burke</p>
<table border="0" width="100%" cellspacing="0" cellpadding="3">
<tr><td class="block" style="background-color: #cccccc" valign="middle">
<big><strong><span class="block">&nbsp;perlpodspec - Plain Old Documentation: format specification and notes</span></strong></big>
</td></tr>
</table>

</body>

</html>
